# coding: utf-8

# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# pylint: disable=too-many-lines
"""Constants."""

UNK_TOKEN = '<unk>'

BOS_TOKEN = '<bos>'

EOS_TOKEN = '<eos>'

PAD_TOKEN = '<pad>'

UNK_IDX = 0   # This should not be changed as long as serialized token
              # embeddings redistributed on S3 contain an unknown token.
              # Blame this code change and see commit for more context.

LARGE_POSITIVE_FLOAT = 1e18

LARGE_NEGATIVE_FLOAT = -LARGE_POSITIVE_FLOAT

GLOVE_NPZ_SHA1 = \
    {'glove.42B.300d': ('glove.42B.300d.npz',
                        '7deee8f4860744db53ed9e50892effe9883e6d89'),
     'glove.6B.100d': ('glove.6B.100d.npz',
                       '01f80f202fcabcc3e0804898349087bfc191dd1c'),
     'glove.6B.200d': ('glove.6B.200d.npz',
                       '5e6e2bdab346c257f88d80d215d518e680d86e32'),
     'glove.6B.300d': ('glove.6B.300d.npz',
                       '1db264aa936be62f055dfb72854204450bdf4399'),
     'glove.6B.50d': ('glove.6B.50d.npz',
                      'aa16be8d184399d2199f83fd62586f2c30497bfa'),
     'glove.840B.300d': ('glove.840B.300d.npz',
                         'b4ba390c1154736e07c0e67d9180935f5930e83c'),
     'glove.twitter.27B.100d': ('glove.twitter.27B.100d.npz',
                                '0f7b82c223451d0002f79ba23596983cdbe0e2b1'),
     'glove.twitter.27B.200d': ('glove.twitter.27B.200d.npz',
                                '41cc2d26f58a54622ce96bf6c8434360ab524f20'),
     'glove.twitter.27B.25d': ('glove.twitter.27B.25d.npz',
                               '9f563d2f296995598cc46812b2fda05ad4c3c879'),
     'glove.twitter.27B.50d': ('glove.twitter.27B.50d.npz',
                               'ce9959c056f2a0a780c468feeb4f823af51630e9')}

FAST_TEXT_NPZ_SHA1 = \
    {'crawl-300d-2M': ('crawl-300d-2M.npz',
                       '9dd611a1fe280c63050cd546d3595400fc0eede4'),
     'wiki.aa': ('wiki.aa.npz',
                 '48f163b80eb37f1806142169d3d4c05cf75b7339'),
     'wiki.ab': ('wiki.ab.npz',
                 '860ceff119dd27e5b701b605879037c1310cbc3e'),
     'wiki.ace': ('wiki.ace.npz',
                  '62938287464040491719f56a6f521f8f808beee8'),
     'wiki.ady': ('wiki.ady.npz',
                  '646843afa260d018ed711df3f1ca9c3e000447b6'),
     'wiki.af': ('wiki.af.npz',
                 '7b14cd27690b67fea318d0bac2283c16430680e2'),
     'wiki.ak': ('wiki.ak.npz',
                 '20f309adad1c45958c97b6055d5838e05bbaea72'),
     'wiki.als': ('wiki.als.npz',
                  'a8b03aa133c4f7da12fc27c2b167b7918b1e9805'),
     'wiki.am': ('wiki.am.npz',
                 'ed3dd10cea64737f7a1623612ee099df9dc19f66'),
     'wiki.ang': ('wiki.ang.npz',
                  '8efe64706d9d6b8eae38b2c7ff0b277e20592bc7'),
     'wiki.an': ('wiki.an.npz',
                 '168046283c719ab96a29b1abae2e25a6575c7be8'),
     'wiki.arc': ('wiki.arc.npz',
                  '049021b7decea4bc009b12936e56b4dbf5b760e7'),
     'wiki.ar': ('wiki.ar.npz',
                 '7e325e1e98dfcdc9368d2ebe40ee834a2ed44912'),
     'wiki.arz': ('wiki.arz.npz',
                  '7d851c2c7be3ee6f7fd896de7b76ea08e3fb08b0'),
     'wiki.as': ('wiki.as.npz',
                 '01d38c29cd4bd99c1a8534abc058822da14a5b9c'),
     'wiki.ast': ('wiki.ast.npz',
                  '9c9846ba5084505a0adea89c95c66e04efbf5ce9'),
     'wiki.av': ('wiki.av.npz',
                 '7ef6a920c364638504e673cfde5f7675503fa81e'),
     'wiki.ay': ('wiki.ay.npz',
                 'c1202e110930e3902397f5cb64a8359e013b469f'),
     'wiki.azb': ('wiki.azb.npz',
                  '10351b7ef14ec2cb610d290cb6a3f6987ef5d8b3'),
     'wiki.az': ('wiki.az.npz',
                 '74257c3bcd533a606afae509ea835dc036d61546'),
     'wiki.ba': ('wiki.ba.npz',
                 '4a2857ed694d66864df562b376c2fa12fcb03646'),
     'wiki.bar': ('wiki.bar.npz',
                  'e65c6b7e9ff83798d1eea05d166148837d53e615'),
     'wiki.bat_smg': ('wiki.bat_smg.npz',
                      '6420584ae28ba6c9dd145fea8f096243d457c2d8'),
     'wiki.bcl': ('wiki.bcl.npz',
                  '33606c970ab336b678393e2bdb8af2116d11cf7b'),
     'wiki.be': ('wiki.be.npz',
                 '84487d341e333344cf71bc12c7a205d923762498'),
     'wiki.bg': ('wiki.bg.npz',
                 '56f2a175b1a1d1a9cf9f1cea277cd0b46ffd7f66'),
     'wiki.bh': ('wiki.bh.npz',
                 '07473989853a344a41aaa18f41030dc56d0d01c7'),
     'wiki.bi': ('wiki.bi.npz',
                 '08adfa3c9ef3016d30ef69ea539d217ff67eda09'),
     'wiki.bjn': ('wiki.bjn.npz',
                  '998a551283222931d3a26922308449950bfa3ec7'),
     'wiki.bm': ('wiki.bm.npz',
                 '454ff9fbd4790e4a076d9a2087a51da28aa1332f'),
     'wiki.bn': ('wiki.bn.npz',
                 '1f36f6f39c9a9b33bb8035c9a4dc7e04933604fd'),
     'wiki.bo': ('wiki.bo.npz',
                 'b9fe87318428de0a7790de175b5fec80c5af482d'),
     'wiki.bpy': ('wiki.bpy.npz',
                  '5c7853173d27e2c018c24eca69de8d5f34511b0d'),
     'wiki.br': ('wiki.br.npz',
                 '7aa66a2034fbfaa1d39e637385d48610238797c9'),
     'wiki.bs': ('wiki.bs.npz',
                 'a019a4677677c2e9e4d899326b2b6c15ad6c011a'),
     'wiki.bug': ('wiki.bug.npz',
                  '09ae3477941d7a99d1df494368d7efb0b2c18913'),
     'wiki.bxr': ('wiki.bxr.npz',
                  'b832c691b8ddd95896c052d3d15e1f98d72068d5'),
     'wiki.ca': ('wiki.ca.npz',
                 '391e0d4daad08649251274fa1cc2a5f49c7728b1'),
     'wiki.cbk_zam': ('wiki.cbk_zam.npz',
                      '02e57a763bc9f9eadaba57953383dd12a0a78a37'),
     'wiki.cdo': ('wiki.cdo.npz',
                  'd6e8f422327e8b2273f1f2662d793707ece6695d'),
     'wiki.ceb': ('wiki.ceb.npz',
                  '23bc0bb9aeaa57dff35092766941a866de142aae'),
     'wiki.ce': ('wiki.ce.npz',
                 '182b2a889256119a6d379d501c55c7621e5855db'),
     'wiki.ch': ('wiki.ch.npz',
                 '82dd77512fcb463481f43c9cef3507e2baa90d7b'),
     'wiki.cho': ('wiki.cho.npz',
                  'b0b620fc2442d1a6e2440e71a424861c80175f0c'),
     'wiki.chr': ('wiki.chr.npz',
                  '3d62c6b95c5af46abd6234426ae760cca65d5bd0'),
     'wiki.chy': ('wiki.chy.npz',
                  '34a28a22da79aebc100e3714b825c95c8d5f54a3'),
     'wiki.ckb': ('wiki.ckb.npz',
                  'ad19461e4be583d08b7693ff5b1e9d590ed41add'),
     'wiki.co': ('wiki.co.npz',
                 'fa60d9f0e79f1c7e15f381aef983a0f4f31c05a8'),
     'wiki.crh': ('wiki.crh.npz',
                  '540270ba6edd9d7b2f7efca52b3b407524ac67d1'),
     'wiki.cr': ('wiki.cr.npz',
                 'f06b77465a38ec960d7d5a7554b848c37e945c76'),
     'wiki.csb': ('wiki.csb.npz',
                  'b8b28559cf2541341af98e2aa755856765bdeabf'),
     'wiki.cs': ('wiki.cs.npz',
                 '19881e931fe06abf341450f00c342d364313e232'),
     'wiki.cu': ('wiki.cu.npz',
                 '731e0d00abd53bc2a8eb6cf37f6ab883cff34e15'),
     'wiki.cv': ('wiki.cv.npz',
                 'e60034fcffb7dfef7b236ddba1194c3aa20b7967'),
     'wiki.cy': ('wiki.cy.npz',
                 '5a0fb967b5556f007c0d5065f951a3d3b1c1005a'),
     'wiki.da': ('wiki.da.npz',
                 'd06258014ba2c7450bc2d55edfdf1731433e42e5'),
     'wiki.de': ('wiki.de.npz',
                 'a21694dfd2af63bd7bb00f0b60b28e88bd1153f1'),
     'wiki.diq': ('wiki.diq.npz',
                  '4f6c77a86b39834a7130419967759afd8cc26b84'),
     'wiki.dsb': ('wiki.dsb.npz',
                  'e74f1d346a8db96987bff0c33ee5f886907c380a'),
     'wiki.dv': ('wiki.dv.npz',
                 '5d6fe6f0eec2e7704121d5aba03b4edbb28af873'),
     'wiki.dz': ('wiki.dz.npz',
                 '77c639d36d0355b2de5adead7996eae342b852a6'),
     'wiki.ee': ('wiki.ee.npz',
                 '4b5a76127d57515d3e8a76787cdefde5856b754a'),
     'wiki.el': ('wiki.el.npz',
                 'a00bcb97e7898931196a1c69f7a492e5b6202661'),
     'wiki.eml': ('wiki.eml.npz',
                  'b475d626b3d97e7a68c02827fdc7900599e838c6'),
     'wiki.en': ('wiki.en.npz',
                 'ad5ec6d49db6c6fe76b8e85ff05d34e5d0e1eb6a'),
     'wiki.eo': ('wiki.eo.npz',
                 '18049b0010520d13e676f5a82e8bb90153d99003'),
     'wiki.es': ('wiki.es.npz',
                 'a6d192ba7d82d762f8367e75ca951aad4d11e410'),
     'wiki.et': ('wiki.et.npz',
                 '4beb7025cf88f1aa62d025b187f0cb09aee61858'),
     'wiki.eu': ('wiki.eu.npz',
                 '5e1a8197e35f20a2476798bbb935b4c131289c4f'),
     'wiki.ext': ('wiki.ext.npz',
                  '049b2d1b0a8b102b45907cf487cac30aa294e0a0'),
     'wiki.fa': ('wiki.fa.npz',
                 '81ed274997c87ef87d73d25e166ca06272ce426f'),
     'wiki.ff': ('wiki.ff.npz',
                 '4867dc74cd53ca0b0f769af4fa1ea420406b59bf'),
     'wiki.fi': ('wiki.fi.npz',
                 '6d1291b854045179f8171ac7d62ede7d8ac159a2'),
     'wiki.fiu_vro': ('wiki.fiu_vro.npz',
                      'dd87806d9dc8833fa0e21e35a50815ebdbaa6c8b'),
     'wiki.fj': ('wiki.fj.npz',
                 'cf5c31b0a69276f5dd18ab738ed92444abaeb755'),
     'wiki.fo': ('wiki.fo.npz',
                 'ffc19807d528af000861a94cfb8097bd686e14fc'),
     'wiki.fr': ('wiki.fr.npz',
                 '8f06d5dbe3cf7214354fe9b2f6eca0ef7419f063'),
     'wiki.frp': ('wiki.frp.npz',
                  'c8b200ae592478d3cd0bfaafcd7aa19de8a3bfe5'),
     'wiki.frr': ('wiki.frr.npz',
                  'fa5e5c39ea2a45793c679eacea290a35e37405ea'),
     'wiki.fur': ('wiki.fur.npz',
                  'a61a8940d059f25000e3fe23933e5ed0d37e65d3'),
     'wiki.fy': ('wiki.fy.npz',
                 '46f9f41bdf6f4fb8e27a753290413d745465963b'),
     'wiki.gag': ('wiki.gag.npz',
                  '49fb01230e6803544122d47ab7d3fe694d1444f2'),
     'wiki.gan': ('wiki.gan.npz',
                  '716b7b26acc15975f30caf3c6effa111516fcca5'),
     'wiki.ga': ('wiki.ga.npz',
                 'ea934bc1fdc1acf6caf9ac746c6c499251f1fdee'),
     'wiki.gd': ('wiki.gd.npz',
                 '597017b5a32d933f194595d3656f858e37e70a62'),
     'wiki.glk': ('wiki.glk.npz',
                  '91a5834658bc2d48714e8807ef24efb79567b4b5'),
     'wiki.gl': ('wiki.gl.npz',
                 '2fa8e48d6ae1e9c9d542eb3f2156cf9e359e66c2'),
     'wiki.gn': ('wiki.gn.npz',
                 'e359eef3928e1f1b5d8fcf0ea532e8794c66289a'),
     'wiki.gom': ('wiki.gom.npz',
                  '8cd361481c23f7545cc2bd8f1bf22aa7400edd4d'),
     'wiki.got': ('wiki.got.npz',
                  'd05daf105611150695e61775fdff2c500b36be3f'),
     'wiki.gu': ('wiki.gu.npz',
                 '0ce175c5fc39bab4032892f70c9d2bb850af0f4a'),
     'wiki.gv': ('wiki.gv.npz',
                 '2c573f873d607831ff01b64603c17b8db79bd7e1'),
     'wiki.hak': ('wiki.hak.npz',
                  'e6048727799cdf149f5c50037e0fc59300d33a94'),
     'wiki.ha': ('wiki.ha.npz',
                 'f18ea7286bbd390c5470896b2c99cb1adc740064'),
     'wiki.haw': ('wiki.haw.npz',
                  '18bcd85d2e06b1b889f0835fc5b62697fdf32d72'),
     'wiki.he': ('wiki.he.npz',
                 '76915ff167b6ecb7b7e22ff0ca46914a55d344af'),
     'wiki.hif': ('wiki.hif.npz',
                  '12153aaf98d76d5502ab77a27cd0b9a539f61513'),
     'wiki.hi': ('wiki.hi.npz',
                 '249666a598991f6ec147954c6af9e531fd1cd94e'),
     'wiki.ho': ('wiki.ho.npz',
                 '3f804fd69780c0789708b56ea9d48715f8e38f26'),
     'wiki.hr': ('wiki.hr.npz',
                 '9a3de28e69f97048bfb480b4f83eaab6149f66ad'),
     'wiki.hsb': ('wiki.hsb.npz',
                  '7070bf64e13299dd66ac0e9f8e24011a56b6bfe8'),
     'wiki.ht': ('wiki.ht.npz',
                 'a607093d511afeb584d02dc676bc5a27eff66287'),
     'wiki.hu': ('wiki.hu.npz',
                 '9b2c4750daf1bcf39768572e874b5afda0e2f0bc'),
     'wiki.hy': ('wiki.hy.npz',
                 'ec0461a102a6fb00bd324f66cefd3c8d55a7093a'),
     'wiki.hz': ('wiki.hz.npz',
                 '5dfb8afbdae6b4148c3e55ab459c56a74b46b463'),
     'wiki.ia': ('wiki.ia.npz',
                 '4cfaaf053b9513bbf5b2423258c0f01d20256de6'),
     'wiki.id': ('wiki.id.npz',
                 'bace396bb9941cc9e5b2e5f5a19be6db833c5fd4'),
     'wiki.ie': ('wiki.ie.npz',
                 '1bae7256c2e763ce6d692d1c0a603d99a8b22826'),
     'wiki.ig': ('wiki.ig.npz',
                 '23128e54a5e143891d392d621723bad9cfc8cf7b'),
     'wiki.ii': ('wiki.ii.npz',
                 '54bc16d05da512481865a89ecf30260b0acc04dc'),
     'wiki.ik': ('wiki.ik.npz',
                 'f8015227e893d2375699b7d132b306ba381f02ac'),
     'wiki.ilo': ('wiki.ilo.npz',
                  '185a11f81bd5d24a34558dda81ee4735f5ba150b'),
     'wiki.io': ('wiki.io.npz',
                 'ddf8180a90aa6ee5be93a2582cc99c535f21363e'),
     'wiki.is': ('wiki.is.npz',
                 '968f8dd2a093b279a6f7aaa734008454bf51d724'),
     'wiki.it': ('wiki.it.npz',
                 'fdfb857a309b2c3d29482bb5cc55f21b858d2e6f'),
     'wiki.iu': ('wiki.iu.npz',
                 'fa8896730bd6c24c3473daa22116d1016294e7f7'),
     'wiki.jam': ('wiki.jam.npz',
                  'a8f0d0b99c89ace0a6401b8fcda261d06065faaf'),
     'wiki.ja': ('wiki.ja.npz',
                 '8d42e5a40e4d1d8645b2d80b873a65cadcf68b5c'),
     'wiki.jbo': ('wiki.jbo.npz',
                  '145fc999ab004b348cf9bf445f0a93a7a145308b'),
     'wiki.jv': ('wiki.jv.npz',
                 '66978770bf06e42414395cf5fd8c596044d72bec'),
     'wiki.kaa': ('wiki.kaa.npz',
                  '624a640ecb9901b2aba2e9f44ab615146ecb2862'),
     'wiki.kab': ('wiki.kab.npz',
                  'e97f93b6ba65e95c85b7541932cf53c5ad9eb896'),
     'wiki.ka': ('wiki.ka.npz',
                 '1ca8376e1e0cbd58001c1b51a2d488a2874a6743'),
     'wiki.kbd': ('wiki.kbd.npz',
                  'f2d2a05b06723ac549784ad5470d84f5742a1352'),
     'wiki.kg': ('wiki.kg.npz',
                 'fa7f6d5f660a173a3e75342d449980eedcdc789e'),
     'wiki.ki': ('wiki.ki.npz',
                 '21a8c7c616c0050c51c288861f3423f313e4f634'),
     'wiki.kj': ('wiki.kj.npz',
                 'f3c347509a0d81f4f7fdbb8b22889b8d76e5014e'),
     'wiki.kk': ('wiki.kk.npz',
                 'bc24a3289e1c1e18e16b6789c2f9f92af1e73071'),
     'wiki.kl': ('wiki.kl.npz',
                 'b8b7e7359f067836e2be2ecfe9f35a820b00fe1d'),
     'wiki.km': ('wiki.km.npz',
                 'e053799fd01463808432dc035bef3e36620e2f36'),
     'wiki.kn': ('wiki.kn.npz',
                 '2849a0a8b3453e9bf6af05d4c7bd3db881dd1068'),
     'wiki.koi': ('wiki.koi.npz',
                  'a9b02e9bd41833bcd54769f94626019c03f29997'),
     'wiki.ko': ('wiki.ko.npz',
                 '764d9896e74b5a26c6884d48bce3bed8ed3a7822'),
     'wiki.krc': ('wiki.krc.npz',
                  'bfe39598c718f1cc95909db7544b3214b308a97c'),
     'wiki.kr': ('wiki.kr.npz',
                 '1e6af853d4a8ea7830e116eb9b61ac5d7d9a315c'),
     'wiki.ksh': ('wiki.ksh.npz',
                  '66cd0e3e0a0b0282a13960571ebe7cddd7706bf2'),
     'wiki.ks': ('wiki.ks.npz',
                 '85f1adaa05b854df4dede745a1aaab3836e60770'),
     'wiki.ku': ('wiki.ku.npz',
                 'faf90584e5a45e6d0f9eeb88399b82abe037d584'),
     'wiki.kv': ('wiki.kv.npz',
                 '9f2b41822013a412da9c99fac06eed8be03ca192'),
     'wiki.kw': ('wiki.kw.npz',
                 '3eed8a8fc97a2fc79241b8474a458c98d00fc897'),
     'wiki.ky': ('wiki.ky.npz',
                 '0116ff90f10a6c0728e1ea86d8a44896ea83270a'),
     'wiki.lad': ('wiki.lad.npz',
                  '5af2015b3d1c5e8563f0e92721580988ebe2ce50'),
     'wiki.la': ('wiki.la.npz',
                 '7143303a3ea13c7668eb90ea6e3d2ca69857a3be'),
     'wiki.lbe': ('wiki.lbe.npz',
                  'f206a3c35a184ba5d2b32ee68640eadf66c847da'),
     'wiki.lb': ('wiki.lb.npz',
                 '143dc6337f3690379282034c460c613d7f144923'),
     'wiki.lez': ('wiki.lez.npz',
                  'b29a680decc6b29f24e8eb9e4f8e11e3419d45f1'),
     'wiki.lg': ('wiki.lg.npz',
                 '866640ce62cedbc1d453b7ea3c289c291ad76e13'),
     'wiki.lij': ('wiki.lij.npz',
                  '0dcd3d7009ae89b1016ca6cdb99a9f0d70bc4baf'),
     'wiki.li': ('wiki.li.npz',
                 '4666b3c238256d7b7623a136db19b8b9f4754734'),
     'wiki.lmo': ('wiki.lmo.npz',
                  'ac89fa7cfe0675950bcb31c66bf3f88a3cfc98f0'),
     'wiki.ln': ('wiki.ln.npz',
                 'fba158719944aabe58e0002a90be0ed77e11702d'),
     'wiki.lo': ('wiki.lo.npz',
                 '1e113e340a8a93d385e14502c9c4e3bcdf6c3101'),
     'wiki.lrc': ('wiki.lrc.npz',
                  '42cb755f398fba6f0da7949c91e92b55654bd482'),
     'wiki.ltg': ('wiki.ltg.npz',
                  '182f75859e228d1162215f28fe7f2dca127624a4'),
     'wiki.lt': ('wiki.lt.npz',
                 '66aa944bd2e777cb82d6d59b1f2f837b6c48cb37'),
     'wiki.lv': ('wiki.lv.npz',
                 '2be8f926da85694fa998bf79d80b61ebb8d67576'),
     'wiki.mai': ('wiki.mai.npz',
                  'b8a9c36e2a0f1bb84a44dc762250d2a9007ef637'),
     'wiki.map_bms': ('wiki.map_bms.npz',
                      '6f0394d6b3d08a946e3df4b9355efe94148f018a'),
     'wiki.mdf': ('wiki.mdf.npz',
                  '774ee35334641db57f9ac9069961c5372a5d92e8'),
     'wiki.mg': ('wiki.mg.npz',
                 '496c48ef668f08ce95ebb11ce1ce5026b52d935c'),
     'wiki.mh': ('wiki.mh.npz',
                 '352edd84f99c5aa277a7306f6cacea1fab065ed3'),
     'wiki.mhr': ('wiki.mhr.npz',
                  'dd78b27a674ac10411cdf74ac32f9391506b17e0'),
     'wiki.min': ('wiki.min.npz',
                  '628b406441ab03bc8aa68195ada50bfdc8226f34'),
     'wiki.mi': ('wiki.mi.npz',
                 '754127b473861cd4f9ae034c9f527a34827b1f00'),
     'wiki.mk': ('wiki.mk.npz',
                 'b09fed4f56c296f13c4020ef1fec498382a38b73'),
     'wiki.ml': ('wiki.ml.npz',
                 '02fb55d97ca2f0408f0e7e8dd6a661bbc3319a2a'),
     'wiki.mn': ('wiki.mn.npz',
                 '08b2c45689aa5d9ec49df96dc7c777ce9b9a0b4b'),
     'wiki.mo': ('wiki.mo.npz',
                 '638c2e8bd2352fd52921b9ae62f578b8357bab49'),
     'wiki.mrj': ('wiki.mrj.npz',
                  'ec5cf1f4fb8dfdca64d8172974e620eb8fa41626'),
     'wiki.mr': ('wiki.mr.npz',
                 '074dd68c947c2f137a3e84b55012925f00213139'),
     'wiki.ms': ('wiki.ms.npz',
                 '3dbe9e9d70251de8a374776ff1250a9c3103ee59'),
     'wiki.mt': ('wiki.mt.npz',
                 'f5103998a68d1b178387417436a83123d44aba01'),
     'wiki.multi.ar': ('wiki.multi.ar.npz',
                       'a010d1d81a465c56ebaf596b3e8e8795e7f0f8e3'),
     'wiki.multi.bg': ('wiki.multi.bg.npz',
                       'c04018f3a600cee170f12a36cdd35b4727a2aade'),
     'wiki.multi.ca': ('wiki.multi.ca.npz',
                       'eef52a0cf20c133ca9065de25f0702861a8cfa29'),
     'wiki.multi.cs': ('wiki.multi.cs.npz',
                       'c5f547aa78c0e3d7dae67a0334d500bf2a86aa30'),
     'wiki.multi.da': ('wiki.multi.da.npz',
                       '24374f2ee169b33327feeee46da31b0de1622fe4'),
     'wiki.multi.de': ('wiki.multi.de.npz',
                       '2e6c119b345bebd34b56eaaf855d6703889b11f7'),
     'wiki.multi.el': ('wiki.multi.el.npz',
                       '9d122beedb80a2e5334946641e5bafd32c01e76b'),
     'wiki.multi.en': ('wiki.multi.en.npz',
                       '8c3c480b4cb2690304173713a646280613b244a8'),
     'wiki.multi.es': ('wiki.multi.es.npz',
                       '483a22656e4fb2a01e9f4ef8156b261e780850ab'),
     'wiki.multi.et': ('wiki.multi.et.npz',
                       '22498c7b91645a3874fa738b5cfb16bf98b6f97c'),
     'wiki.multi.fi': ('wiki.multi.fi.npz',
                       '765a6f0b63777bff4ae6ca2b461c5889c03d6a70'),
     'wiki.multi.fr': ('wiki.multi.fr.npz',
                       'decd9aacf600114b8a36072535c0309874a37c83'),
     'wiki.multi.he': ('wiki.multi.he.npz',
                       '7eee940c1b85936f59122f4b1a166223dd946674'),
     'wiki.multi.hr': ('wiki.multi.hr.npz',
                       '1673963416af088f8bf15576afb33d58115db35c'),
     'wiki.multi.hu': ('wiki.multi.hu.npz',
                       'a1fbe6ededf3cbaa3eaa22dd8b20cce4b36cfc6d'),
     'wiki.multi.id': ('wiki.multi.id.npz',
                       '6c3e721febb511ede7db7bf978d65769e4270f5c'),
     'wiki.multi.it': ('wiki.multi.it.npz',
                       'fc5bfc11e0165e8d95c1708573dad5e456826c73'),
     'wiki.multi.mk': ('wiki.multi.mk.npz',
                       '6cd50198355674f156fc863108d9bebf11cfabd9'),
     'wiki.multi.nl': ('wiki.multi.nl.npz',
                       '4fa06b9230c95dfa5a9e9a5d80f1f5ba614d3cbf'),
     'wiki.multi.no': ('wiki.multi.no.npz',
                       '63756168c1101e73fba8d1a5015f32b8892819e6'),
     'wiki.multi.pl': ('wiki.multi.pl.npz',
                       '958b8e8bead965ba1bb1433e1c960fc3e12a10fb'),
     'wiki.multi.pt': ('wiki.multi.pt.npz',
                       '22f07df1609d79b95344ee575ea43141424a1528'),
     'wiki.multi.ro': ('wiki.multi.ro.npz',
                       '73180b3e382519004bf38ea7b86237aacbbe813a'),
     'wiki.multi.ru': ('wiki.multi.ru.npz',
                       '3b2eb9163f35e90bf2ce1cd3c997b354d0c34f59'),
     'wiki.multi.sk': ('wiki.multi.sk.npz',
                       '606a0c3ba9849070c6b6b8c22d920fdeed9a1385'),
     'wiki.multi.sl': ('wiki.multi.sl.npz',
                       '3cfdab5043b8cfe1535cb6dbd4c9e68847ad5904'),
     'wiki.multi.sv': ('wiki.multi.sv.npz',
                       '4f1494885b9a831e87cfa3c15f2204c4a73c0779'),
     'wiki.multi.tr': ('wiki.multi.tr.npz',
                       '54f90d5ddb9a65538a41e37c5a67ed933a5e4885'),
     'wiki.multi.uk': ('wiki.multi.uk.npz',
                       '500fd26b1d7a25b42458012e99f9f76642e0c787'),
     'wiki.multi.vi': ('wiki.multi.vi.npz',
                       '3955809cceb300965c15f9372221417719bb0db8'),
     'wiki.mus': ('wiki.mus.npz',
                  'a5f48934a3fa6eaf4929098046c93fc94dd6bcb6'),
     'wiki.mwl': ('wiki.mwl.npz',
                  '8a5e2c272166f8a72c5694ca6c3104d5f49179ec'),
     'wiki.my': ('wiki.my.npz',
                 '5e035aca16700d7d6695af8a6d3a88ac847aaeb7'),
     'wiki.myv': ('wiki.myv.npz',
                  'd4cfaab70c640033e02c0fc0c5a3615ae836c569'),
     'wiki.mzn': ('wiki.mzn.npz',
                  'ad09ac584ae455b5862b95125ef409360ae18445'),
     'wiki.nah': ('wiki.nah.npz',
                  '2dc454ef37d059f2053af46cfa1f4f0ca939cba0'),
     'wiki.na': ('wiki.na.npz',
                 '401f0f880eb7aa78d21348bc1e0a3953b3e81bf0'),
     'wiki.nap': ('wiki.nap.npz',
                  '996da46aeeab5644ba766d00c5e343b1553361d7'),
     'wiki.nds_nl': ('wiki.nds_nl.npz',
                     '5a9307e16b13a5a82ec19a52b33254537e7198e7'),
     'wiki.nds': ('wiki.nds.npz',
                  'b249a87c78c52becf51e7b50aaf9f9b6a36585f1'),
     'wiki.ne': ('wiki.ne.npz',
                 'a601db2647a74ffd2b4b43dcb8584735f555459c'),
     'wiki.new': ('wiki.new.npz',
                  'c398a3775aba9c68ce765cfdfb6b188f7c47e4c6'),
     'wiki-news-300d-1M': ('wiki-news-300d-1M.npz',
                           '0a03bbd508e5381e140476140fb121afeb0050ed'),
     'wiki-news-300d-1M-subword': ('wiki-news-300d-1M-subword.npz',
                                   '69edae21375407781c727dcb9e534e79d712d137'),
     'wiki.ng': ('wiki.ng.npz',
                 'befd774d15f69d43547e13e5ea3a97c4cb1ab405'),
     'wiki.nl': ('wiki.nl.npz',
                 '5a7cb6f1dd0a7621202abba9461ac2c5bf905219'),
     'wiki.nn': ('wiki.nn.npz',
                 '8e5059ddeb24050fadaa5cc4622b13feb3e4a226'),
     'wiki.no': ('wiki.no.npz',
                 '5ce6e0f793e66f081652f64013968099de03d9f9'),
     'wiki.nov': ('wiki.nov.npz',
                  '95ed23b4cfd7a65afa1c12c7dbdce6af53923d77'),
     'wiki.vec': ('wiki.vec.npz',
                  '08ebb912efeb9df1c7d05e1af90484d210dff47e'),
     'wiki.nrm': ('wiki.nrm.npz',
                  'e58614b4508ff9810f0b58fd818f973775bc918d'),
     'wiki.nso': ('wiki.nso.npz',
                  '56a2ebe260241402d117cd89c5c872b9c96ff05b'),
     'wiki.nv': ('wiki.nv.npz',
                 'c713051fe03ec1f60314bb42161b2a47fb5e169a'),
     'wiki.ny': ('wiki.ny.npz',
                 'ba5a1725955cbc13e7fd93ab499f8085840c992c'),
     'wiki.oc': ('wiki.oc.npz',
                 '259e7d994c38a4cfc140fb07016b82d6781e5027'),
     'wiki.olo': ('wiki.olo.npz',
                  '0fea70f887def4779ee70a79366b88f1ada65004'),
     'wiki.om': ('wiki.om.npz',
                 '47e2d756b5f8913085d901375c1b4e0b118a4221'),
     'wiki.or': ('wiki.or.npz',
                 '7e274ab060219b019aa02bb97941cc6e162fd01f'),
     'wiki.os': ('wiki.os.npz',
                 '19e8199cc2aaffdb07b6c558dbc5465ac6e03155'),
     'wiki.pag': ('wiki.pag.npz',
                  'eddf4931547649026c02f893297ef673ec6158bb'),
     'wiki.pam': ('wiki.pam.npz',
                  '40109aa174bd9f0fa657839bb548e2b0646c58d3'),
     'wiki.pa': ('wiki.pa.npz',
                 '8a5870717e9e641b1f757f13259171698118de2e'),
     'wiki.pap': ('wiki.pap.npz',
                  '999c8e5b005ca20d9998fbbe4fa79177f69e24c0'),
     'wiki.pcd': ('wiki.pcd.npz',
                  'e975066b323a65cdc5e4c27138ef674d2cf7250b'),
     'wiki.pdc': ('wiki.pdc.npz',
                  '5c770b9d56f276b0aa535845f175c05ee1cea615'),
     'wiki.pfl': ('wiki.pfl.npz',
                  '0063d0b633ee529a75482b36ed4f4da7d64994ec'),
     'wiki.pih': ('wiki.pih.npz',
                  'ce1d76c94d248545eea0d7436c54849dbb380bfc'),
     'wiki.pi': ('wiki.pi.npz',
                 'c7d56c334bf529f8b3655693d207a80feaec4aed'),
     'wiki.pl': ('wiki.pl.npz',
                 '0d612fdf871a1a4084c867f394940475be899443'),
     'wiki.pms': ('wiki.pms.npz',
                  'ca149a2fb138011315bb6d5d61c7a5647e515e51'),
     'wiki.pnb': ('wiki.pnb.npz',
                  '9ec82d02ad8894056c67991cf8ce927bcca74ee2'),
     'wiki.pnt': ('wiki.pnt.npz',
                  '3f90123407bb8fc838a0a0d3700a14e15f5b26aa'),
     'wiki.ps': ('wiki.ps.npz',
                 '7edebc02ac16f5fab83eb10b7d0fab821a9a4d43'),
     'wiki.pt': ('wiki.pt.npz',
                 'f172fd801edd1ad9d319ba44146d40b5d682a473'),
     'wiki.qu': ('wiki.qu.npz',
                 '68bec60ccfe1826c3b3a8968574488dbc74cdf7b'),
     'wiki.rm': ('wiki.rm.npz',
                 '00fb191fc736ba60cb23e76169dfccde9a9daad0'),
     'wiki.rmy': ('wiki.rmy.npz',
                  'c5e93cc37ff7293b9a1d9fe55c42d6fbde372b97'),
     'wiki.rn': ('wiki.rn.npz',
                 '57b8e0d6999269be227af6ef2797a9cf8386ff1b'),
     'wiki.roa_rup': ('wiki.roa_rup.npz',
                      'e06d6b5672a59bb9e83143bc8b28300d23c09546'),
     'wiki.roa_tara': ('wiki.roa_tara.npz',
                       'c083105f40236dc3711f06c1b40e8ee7a714b99d'),
     'wiki.ro': ('wiki.ro.npz',
                 '766bc0cb58a65b0b1763b9a0d90e91ab982eb20d'),
     'wiki.rue': ('wiki.rue.npz',
                  '9a91fa093cd48d7d658d526b0ccda48dc59cd7f4'),
     'wiki.ru': ('wiki.ru.npz',
                 'd59d099481c22d5592ab9635c9ee48060aa0bf45'),
     'wiki.rw': ('wiki.rw.npz',
                 'e99ee87d249f6c157c5c97397d1025d798b85c69'),
     'wiki.sah': ('wiki.sah.npz',
                  '85dae39097b29bc8e2b64f343a77794e4a62f91a'),
     'wiki.sa': ('wiki.sa.npz',
                 '7d1928d7c67400045ac1b35a37a0e3089690d875'),
     'wiki.scn': ('wiki.scn.npz',
                  '27d7b8050bbeed8ce196061c610216760b053c39'),
     'wiki.sc': ('wiki.sc.npz',
                 '69c7b8be0f03a1bbd615695f93bdd78f96a58e16'),
     'wiki.sco': ('wiki.sco.npz',
                  '4880282f59d3338b67fbff75359e2d24896e95bb'),
     'wiki.sd': ('wiki.sd.npz',
                 '0ed8da4d27223db717a612cf0c88582351db6e19'),
     'wiki.se': ('wiki.se.npz',
                 '0f4b2e060d5e29f96ca73aab29c967e79db69c17'),
     'wiki.sg': ('wiki.sg.npz',
                 'a5e4edf34fe1a88b322da4c3922ec5a470e200c6'),
     'wiki.sh': ('wiki.sh.npz',
                 'c13f1e94676bc939560193f7aa7ffd7d604707b3'),
     'wiki.simple': ('wiki.simple.npz',
                     '352d0575e7d60b08e1dfce2c5de713906f0ed78f'),
     'wiki.si': ('wiki.si.npz',
                 '204f9ffbe7770a9f56d3b2fb26999165015f5c33'),
     'wiki.sk': ('wiki.sk.npz',
                 '7a9820b5a343b242660bf2595d1ecbf6e00a76d6'),
     'wiki.sl': ('wiki.sl.npz',
                 '85f3186f26d6725317a64e290363a7251b928b81'),
     'wiki.sm': ('wiki.sm.npz',
                 '9e13452cc4bff677f4f15db04f9d2f95f6ec054c'),
     'wiki.sn': ('wiki.sn.npz',
                 'e8d5f7dcf51280c5f99bc3df849b4889a61e9fcd'),
     'wiki.so': ('wiki.so.npz',
                 '0f5d71b95768b33fd939a870c15344c4478364a9'),
     'wiki.sq': ('wiki.sq.npz',
                 '8b05826df8575e65c87a2fc0b7630cf644d4216d'),
     'wiki.srn': ('wiki.srn.npz',
                  '2711396ef297ac5dde8904508bc002bdecbcc6f4'),
     'wiki.sr': ('wiki.sr.npz',
                 '546edc8e29a5d2e99ed10eb4a552cbef2bb8f417'),
     'wiki.ss': ('wiki.ss.npz',
                 '2e5911bad79bb5270a64f587e326d31c95ec58f3'),
     'wiki.st': ('wiki.st.npz',
                 '23bc954719a2962e891f02efaea754c9ea025894'),
     'wiki.stq': ('wiki.stq.npz',
                  'dd3ece0c0aa30e53ae0f4b558309bb60ab628652'),
     'wiki.su': ('wiki.su.npz',
                 '7e48732e8a1fcf212e692924a4416a6ac3b3b055'),
     'wiki.sv': ('wiki.sv.npz',
                 'b9ec52e9423688f195f3145c243226c0e0b51e83'),
     'wiki.sw': ('wiki.sw.npz',
                 '5262f0c645322b10eca73f792a970f10b2719e55'),
     'wiki.szl': ('wiki.szl.npz',
                  'fdd6d6b291cdbbcec5ff93451a588fdd103bb2d0'),
     'wiki.ta': ('wiki.ta.npz',
                 'da7c5bc6e1142306ff2669bf1739832beb6c1763'),
     'wiki.tcy': ('wiki.tcy.npz',
                  'baa49e1afa2bb0dcaaef0fac1ee75bbe711d1134'),
     'wiki.te': ('wiki.te.npz',
                 'baf48767ce85e4d41d65d25f2bbf1c5f559ec18f'),
     'wiki.tet': ('wiki.tet.npz',
                  '11e46a893af55344dbe102d530fdfea5d949d3bc'),
     'wiki.tg': ('wiki.tg.npz',
                 'da66abb72ec9ccc602713161e544963d59cc51d7'),
     'wiki.th': ('wiki.th.npz',
                 '25e54bf2d305779ec9baa5f344410bd75c7702fc'),
     'wiki.ti': ('wiki.ti.npz',
                 '1faf98f3a0eafa7559a4b2a111f43dd1f7b9a05b'),
     'wiki.tk': ('wiki.tk.npz',
                 '34c714fa8275fd6abfe86b2d144a043774552a6c'),
     'wiki.tl': ('wiki.tl.npz',
                 '7d7f8a0485155bce7a74a1d778824375b0029f53'),
     'wiki.tn': ('wiki.tn.npz',
                 'd0bc3a9b948753ac2283e5e10480c9fa0f6acb53'),
     'wiki.to': ('wiki.to.npz',
                 'e982fc31bcfcf7339988d7aad21ce29ac9e84b0b'),
     'wiki.tpi': ('wiki.tpi.npz',
                  '448cef043fa4b7f97825dbf8ee205ef05543bcac'),
     'wiki.tr': ('wiki.tr.npz',
                 'c9830607a4c5134c6191006f1d80bae0ec798fe6'),
     'wiki.ts': ('wiki.ts.npz',
                 '84a0598803712c8a713943447ddb73fc0f39af43'),
     'wiki.tt': ('wiki.tt.npz',
                 '82c29df18f33e6284af3e977a6dda7e132a7a225'),
     'wiki.tum': ('wiki.tum.npz',
                  '358990b894a3fb09d70674465952d828c9b0eda7'),
     'wiki.tw': ('wiki.tw.npz',
                 '1e6d2838a4f271c1808795fb929cfcbf95094d93'),
     'wiki.ty': ('wiki.ty.npz',
                 'e41ca5192d8cb515b3561c8d6935b150deb027b7'),
     'wiki.tyv': ('wiki.tyv.npz',
                  'ce062ed32e854604714b65698ae290c99ba28060'),
     'wiki.udm': ('wiki.udm.npz',
                  '9e1c5891ee0c5ac8f65fc457e1b42c7b2bfc8d37'),
     'wiki.ug': ('wiki.ug.npz',
                 '656503e54063e200980e39f00fc011395bcd8551'),
     'wiki.uk': ('wiki.uk.npz',
                 '352b7ee24d9fc6513fff4fe13bc04086c680834a'),
     'wiki.ur': ('wiki.ur.npz',
                 'a81e55c7adfc2cef779ce9a01fe21319a7e4943b'),
     'wiki.uz': ('wiki.uz.npz',
                 'd60d1e67bb8574dd71c18c88114aba674fc1eecb'),
     'wiki.ve': ('wiki.ve.npz',
                 '5bfc3dbb3e47d23597df47ef12bd1c64ab8d3ea9'),
     'wiki.vep': ('wiki.vep.npz',
                  '7a94355754fbe56802242c0bf9d7a27335095552'),
     'wiki.vi': ('wiki.vi.npz',
                 'f118039eb16a4ca3347b6b171eac41113350a041'),
     'wiki.vls': ('wiki.vls.npz',
                  '9a46a2fdc6448aa54f212081643745499ea7d05c'),
     'wiki.vo': ('wiki.vo.npz',
                 '8e2f93c85ac608bcc4ae14093b9ff016061378fb'),
     'wiki.wa': ('wiki.wa.npz',
                 '907074f7743d30cdbb2c48d0c8b4040796ea4164'),
     'wiki.war': ('wiki.war.npz',
                  '928fb410c394b9c18d875326b6a3e750e2611e1b'),
     'wiki.wo': ('wiki.wo.npz',
                 '7bb352be44f7261aa926f49b13e77df30f29312f'),
     'wiki.wuu': ('wiki.wuu.npz',
                  '0d1dc7b05867ff2156a1180ad3da3b4697924e59'),
     'wiki.xal': ('wiki.xal.npz',
                  'd87f4a131e086dc0bdc2a7e10406820c3c03b6a9'),
     'wiki.xh': ('wiki.xh.npz',
                 'c64e1d2e77d1c744a628e2bd7353284616e48bea'),
     'wiki.xmf': ('wiki.xmf.npz',
                  '160b9ee9773b9099aaf37ae9bdbc8a4a93b7f6ea'),
     'wiki.yi': ('wiki.yi.npz',
                 '0662542cee29f3392fc905004ac6443b32c1477c'),
     'wiki.yo': ('wiki.yo.npz',
                 '5d12d3b902a1fa19d8548295c3802c0608afa5c8'),
     'wiki.za': ('wiki.za.npz',
                 '536348ff89df62e968739b567a1245bfd4112fbe'),
     'wiki.zea': ('wiki.zea.npz',
                  '61fa192289a7c0f73ffa8035632a38b91c31c224'),
     'wiki.zh_classical': ('wiki.zh_classical.npz',
                           '9acc9eaf8ebe316b945fb1f56ac71a2b7e024854'),
     'wiki.zh_min_nan': ('wiki.zh_min_nan.npz',
                         '5d38bc025c82af578299d60f7df7b399de6ed81a'),
     'wiki.zh': ('wiki.zh.npz',
                 '94007fcf3b105bf2c21b84a3a22bdb7946e74804'),
     'wiki.zh_yue': ('wiki.zh_yue.npz',
                     'af6f0d94e6418d528d6cedd859e07e6e2fb416ab'),
     'wiki.zu': ('wiki.zu.npz',
                 'fc9ce07d5d0c49a3c86cf1b26056ada58f9404ca')}

GOOGLEANALOGY_CATEGORIES = [
    'capital-common-countries', 'capital-world', 'currency', 'city-in-state',
    'family', 'gram1-adjective-to-adverb', 'gram2-opposite',
    'gram3-comparative', 'gram4-superlative', 'gram5-present-participle',
    'gram6-nationality-adjective', 'gram7-past-tense', 'gram8-plural',
    'gram9-plural-verbs'
]

BATS_CHECKSUMS = \
    {'BATS_3.0/1_Inflectional_morphology/I01 [noun - plural_reg].txt':
     'cfcba2835edf81abf11b84defd2f4daa3ca0b0bf',
     'BATS_3.0/1_Inflectional_morphology/I02 [noun - plural_irreg].txt':
     '44dbc56432b79ff5ce2ef80b6840a8aa916524f9',
     'BATS_3.0/1_Inflectional_morphology/I03 [adj - comparative].txt':
     'dc530918e98b467b8102a7dab772a66d3db32a73',
     'BATS_3.0/1_Inflectional_morphology/I04 [adj - superlative].txt':
     '6c6fdfb6c733bc9b298d95013765163f42faf6fb',
     'BATS_3.0/1_Inflectional_morphology/I05 [verb_inf - 3pSg].txt':
     '39fa47ec7238ddb3f9818bc586f23f55b55418d8',
     'BATS_3.0/1_Inflectional_morphology/I06 [verb_inf - Ving].txt':
     '8fabeb9f5af6c3e7154a220b7034bbe5b900c36f',
     'BATS_3.0/1_Inflectional_morphology/I07 [verb_inf - Ved].txt':
     'aa04df95aa2edb436cbcc03c7b15bc492ece52d6',
     'BATS_3.0/1_Inflectional_morphology/I08 [verb_Ving - 3pSg].txt':
     '5f22d8121a5043ce76d3b6b53a49a7bb3fe33920',
     'BATS_3.0/1_Inflectional_morphology/I09 [verb_Ving - Ved].txt':
     '377777c1e793c638e72c010228156d01f916708e',
     'BATS_3.0/1_Inflectional_morphology/I10 [verb_3pSg - Ved].txt':
     '051c0c3c633e10900f827991dac14cf76da7f022',
     'BATS_3.0/2_Derivational_morphology/D01 [noun+less_reg].txt':
     '5d6839e9d34ee1e9fddb5bbf6516cf6420b85d8d',
     'BATS_3.0/2_Derivational_morphology/D02 [un+adj_reg].txt':
     '80b82227a0d5f7377f1e8cebe28c582bfeb1afb5',
     'BATS_3.0/2_Derivational_morphology/D03 [adj+ly_reg].txt':
     '223e120bd61b3116298a253f392654c15ad5a39a',
     'BATS_3.0/2_Derivational_morphology/D04 [over+adj_reg].txt':
     'a56f8685af489bcd09c36f864eba1657ce0a7c28',
     'BATS_3.0/2_Derivational_morphology/D05 [adj+ness_reg].txt':
     '5da99b1f1781ecfb4a1a7448c715abf07451917b',
     'BATS_3.0/2_Derivational_morphology/D06 [re+verb_reg].txt':
     '4c5e1796091fade503fbf0bfc2fae2c7f98b5dd2',
     'BATS_3.0/2_Derivational_morphology/D07 [verb+able_reg].txt':
     'a6218162bc257d98e875fc667c23edfac59e19fd',
     'BATS_3.0/2_Derivational_morphology/D08 [verb+er_irreg].txt':
     '9a4236c3bbc23903e101a42fb5ad6e15e552fadf',
     'BATS_3.0/2_Derivational_morphology/D09 [verb+tion_irreg].txt':
     '3ab0153926d5cf890cf08a4077da6d9946133874',
     'BATS_3.0/2_Derivational_morphology/D10 [verb+ment_irreg].txt':
     '2a012b87a9a60e128e064c5fe24b60f99e16ddce',
     'BATS_3.0/3_Encyclopedic_semantics/E01 [country - capital].txt':
     '9890315d3c4e6a38b8ae5fc441858564be3d3dc4',
     'BATS_3.0/3_Encyclopedic_semantics/E02 [country - language].txt':
     'ef08a00e8ff7802811ace8f00fabac41b5d03678',
     'BATS_3.0/3_Encyclopedic_semantics/E03 [UK_city - county].txt':
     '754957101c93a25b438785bd4458404cd9010259',
     'BATS_3.0/3_Encyclopedic_semantics/E04 [name - nationality].txt':
     '71a6562c34fb6154992a7c3e499375fcc3529c96',
     'BATS_3.0/3_Encyclopedic_semantics/E05 [name - occupation].txt':
     'a9a6f9f1af959aef83106f3dbd6bed16dfe9a3ea',
     'BATS_3.0/3_Encyclopedic_semantics/E06 [animal - young].txt':
     '12d5b51c7b76b9136eadc719abc8cf4806c67b73',
     'BATS_3.0/3_Encyclopedic_semantics/E07 [animal - sound].txt':
     '91991b007a35f45bd42bd7d0d465c6f8311df911',
     'BATS_3.0/3_Encyclopedic_semantics/E08 [animal - shelter].txt':
     'e5af11e216db392986ba0cbb597d861066c29adb',
     'BATS_3.0/3_Encyclopedic_semantics/E09 [things - color].txt':
     'd30b2eb2fc7a60f19afda7c54582e30f6fe28f51',
     'BATS_3.0/3_Encyclopedic_semantics/E10 [male - female].txt':
     '247a588671bc1da8f615e14076bd42573d24b4b3',
     'BATS_3.0/4_Lexicographic_semantics/L01 [hypernyms - animals].txt':
     '4b5c4dabe2c9c038fafee85d8d3958f1b1dec987',
     'BATS_3.0/4_Lexicographic_semantics/L02 [hypernyms - misc].txt':
     '83d5ecad78d9de28fd70347731c7ee5918ba43c9',
     'BATS_3.0/4_Lexicographic_semantics/L03 [hyponyms - misc].txt':
     'a8319856ae2f76b4d4c030ac7e899bb3a06a9a48',
     'BATS_3.0/4_Lexicographic_semantics/L04 [meronyms - substance].txt':
     'c081e1104e1b40725063f4b39d13d1ec12496bfd',
     'BATS_3.0/4_Lexicographic_semantics/L05 [meronyms - member].txt':
     'bcbf05f3be76cef990a74674a9999a0bb9790a07',
     'BATS_3.0/4_Lexicographic_semantics/L06 [meronyms - part].txt':
     '2f9bdcc74b881e1c54b391c9a6e7ea6243b3accc',
     'BATS_3.0/4_Lexicographic_semantics/L07 [synonyms - intensity].txt':
     '8fa287860b096bef004fe0f6557e4f686e3da81a',
     'BATS_3.0/4_Lexicographic_semantics/L08 [synonyms - exact].txt':
     'a17c591961bddefd97ae5df71f9d1559ce7900f4',
     'BATS_3.0/4_Lexicographic_semantics/L09 [antonyms - gradable].txt':
     '117fbb86504c192b33a5469f2f282e741d9c016d',
     'BATS_3.0/4_Lexicographic_semantics/L10 [antonyms - binary].txt':
     '3cde2f2c2a0606777b8d7d11d099f316416a7224'}

BATS_CATEGORIES = {
    'I01': '[noun - plural_reg]',
    'I02': '[noun - plural_irreg]',
    'I03': '[adj - comparative]',
    'I04': '[adj - superlative]',
    'I05': '[verb_inf - 3pSg]',
    'I06': '[verb_inf - Ving]',
    'I07': '[verb_inf - Ved]',
    'I08': '[verb_Ving - 3pSg]',
    'I09': '[verb_Ving - Ved]',
    'I10': '[verb_3pSg - Ved]',
    'D01': '[noun+less_reg]',
    'D02': '[un+adj_reg]',
    'D03': '[adj+ly_reg]',
    'D04': '[over+adj_reg]',
    'D05': '[adj+ness_reg]',
    'D06': '[re+verb_reg]',
    'D07': '[verb+able_reg]',
    'D08': '[verb+er_irreg]',
    'D09': '[verb+tion_irreg]',
    'D10': '[verb+ment_irreg]',
    'E01': '[country - capital]',
    'E02': '[country - language]',
    'E03': '[UK_city - county]',
    'E04': '[name - nationality]',
    'E05': '[name - occupation]',
    'E06': '[animal - young]',
    'E07': '[animal - sound]',
    'E08': '[animal - shelter]',
    'E09': '[things - color]',
    'E10': '[male - female]',
    'L01': '[hypernyms - animals]',
    'L02': '[hypernyms - misc]',
    'L03': '[hyponyms - misc]',
    'L04': '[meronyms - substance]',
    'L05': '[meronyms - member]',
    'L06': '[meronyms - part]',
    'L07': '[synonyms - intensity]',
    'L08': '[synonyms - exact]',
    'L09': '[antonyms - gradable]',
    'L10': '[antonyms - binary]'
}

SEMEVAL17_CHECKSUMS = \
    {'SemEval17-Task2/README.txt':
     'ad02d4c22fff8a39c9e89a92ba449ec78750af6b',
     'SemEval17-Task2/task2-scorer.jar':
     '145ef73ce955656d59e3b67b41f8152e8ee018d8',
     'SemEval17-Task2/test/subtask1-monolingual/data/de.test.data.txt':
     '6fc840f989d2274509549e472a68fb88dd2e149f',
     'SemEval17-Task2/test/subtask1-monolingual/data/en.test.data.txt':
     '05293fcbd80b2f4aad9b6518ce1a546ad8f61f33',
     'SemEval17-Task2/test/subtask1-monolingual/data/es.test.data.txt':
     '552904b5988f9951311290ca8fa0441dd4351d4b',
     'SemEval17-Task2/test/subtask1-monolingual/data/fa.test.data.txt':
     '29d5970feac5982961bd6ab621ba31f83d3bff77',
     'SemEval17-Task2/test/subtask1-monolingual/data/it.test.data.txt':
     'c95fe2be8fab37e9c70610117bdedc48a0a8e95c',
     'SemEval17-Task2/test/subtask1-monolingual/keys/de.test.gold.txt':
     'c51463460495a242cc726d41713c5e00b66fdd18',
     'SemEval17-Task2/test/subtask1-monolingual/keys/en.test.gold.txt':
     '2d2bb2ed41308cc60e7953cc9036f7dc89141b48',
     'SemEval17-Task2/test/subtask1-monolingual/keys/es.test.gold.txt':
     'a5842ff17fe3847d15414924826a8eb236018bcc',
     'SemEval17-Task2/test/subtask1-monolingual/keys/fa.test.gold.txt':
     '717bbe035d8ae2bad59416eb3dd4feb7238b97d4',
     'SemEval17-Task2/test/subtask1-monolingual/keys/it.test.gold.txt':
     'a342b950109c73afdc86a7829e17c1d8f7c482f0',
     'SemEval17-Task2/test/subtask2-crosslingual/data/de-es.test.data.txt':
     'ef92b1375762f68c700e050d214d3241ccde2319',
     'SemEval17-Task2/test/subtask2-crosslingual/data/de-fa.test.data.txt':
     '17aa103981f3193960309bb9b4cc151acaf8136c',
     'SemEval17-Task2/test/subtask2-crosslingual/data/de-it.test.data.txt':
     'eced15e8565689dd67605a82a782d19ee846222a',
     'SemEval17-Task2/test/subtask2-crosslingual/data/en-de.test.data.txt':
     '5cb69370a46385a7a3d37cdf2018744be77203a0',
     'SemEval17-Task2/test/subtask2-crosslingual/data/en-es.test.data.txt':
     '402f7fed52b60e915fb1be49f935395488cf7a7b',
     'SemEval17-Task2/test/subtask2-crosslingual/data/en-fa.test.data.txt':
     '9bdddbbde3da755f2a700bddfc3ed1cd9324ad48',
     'SemEval17-Task2/test/subtask2-crosslingual/data/en-it.test.data.txt':
     'd3b37aac79ca10311352309ef9b172f686ecbb80',
     'SemEval17-Task2/test/subtask2-crosslingual/data/es-fa.test.data.txt':
     'a2959aec346c26475a4a6ad4d950ee0545f2381e',
     'SemEval17-Task2/test/subtask2-crosslingual/data/es-it.test.data.txt':
     'ca627c30143d9f82a37a8776fabf2cee226dd35c',
     'SemEval17-Task2/test/subtask2-crosslingual/data/it-fa.test.data.txt':
     'a03d79a6ce7b798356b53b4e85dbe828247b97ef',
     'SemEval17-Task2/test/subtask2-crosslingual/keys/de-es.test.gold.txt':
     '7564130011d38daad582b83135010a2a58796df6',
     'SemEval17-Task2/test/subtask2-crosslingual/keys/de-fa.test.gold.txt':
     'c9e23c2e5e970e7f95550fbac3362d85b82cc569',
     'SemEval17-Task2/test/subtask2-crosslingual/keys/de-it.test.gold.txt':
     'b74cc2609b2bd2ceb5e076f504882a2e0a996a3c',
     'SemEval17-Task2/test/subtask2-crosslingual/keys/en-de.test.gold.txt':
     '428dfdad2a144642c13c24b845e6b7de6bf5f663',
     'SemEval17-Task2/test/subtask2-crosslingual/keys/en-es.test.gold.txt':
     '1dd7ab08a10552486299151cdd32ed19b56db682',
     'SemEval17-Task2/test/subtask2-crosslingual/keys/en-fa.test.gold.txt':
     '17451ac2165aa9b695dae9b1aba20eb8609fb400',
     'SemEval17-Task2/test/subtask2-crosslingual/keys/en-it.test.gold.txt':
     '5041c0b84a603ed85aa0a5cbe4b1c34f69a2fa7c',
     'SemEval17-Task2/test/subtask2-crosslingual/keys/es-fa.test.gold.txt':
     '8c09a219670dc32ab3864078bf0c28a287accabc',
     'SemEval17-Task2/test/subtask2-crosslingual/keys/es-it.test.gold.txt':
     'b1cdd13209354cc2fc2f4226c80aaa85558daf4a',
     'SemEval17-Task2/test/subtask2-crosslingual/keys/it-fa.test.gold.txt':
     'e0b560bb1d2db39ce45e841c8aad611734dc94f1',
     'SemEval17-Task2/trial/subtask1-monolingual/data/de.trial.data.txt':
     'dd071fd90f59bec8d271a447d86ee2e462941f52',
     'SemEval17-Task2/trial/subtask1-monolingual/data/en.trial.data.txt':
     'e8e5add0850b3dec07f102be26b8791a5e9bbbcf',
     'SemEval17-Task2/trial/subtask1-monolingual/data/es.trial.data.txt':
     '8956c78ff9ceae1d923a57816e55392c6a7dfc49',
     'SemEval17-Task2/trial/subtask1-monolingual/data/fa.trial.data.txt':
     '2f7c4247cde0d918b3508e90f6b49a1f5031c81b',
     'SemEval17-Task2/trial/subtask1-monolingual/data/it.trial.data.txt':
     'c11e0b5b55f94fc97c7b11fa455e71b071be879f',
     'SemEval17-Task2/trial/subtask1-monolingual/keys/de.trial.gold.txt':
     'ce5567b1accf3eb07da53229dfcb2a8a1dfac380',
     'SemEval17-Task2/trial/subtask1-monolingual/keys/en.trial.gold.txt':
     '693cb5928e807c79e39136dc0981dadca7832ae6',
     'SemEval17-Task2/trial/subtask1-monolingual/keys/es.trial.gold.txt':
     '8241ca66bf5ba55f77607e9bcfae8e34902715d8',
     'SemEval17-Task2/trial/subtask1-monolingual/keys/fa.trial.gold.txt':
     'd30701a93c8c5500b82ac2334ed8410f9a23864b',
     'SemEval17-Task2/trial/subtask1-monolingual/keys/it.trial.gold.txt':
     'bad225573e1216ba8b35429e9fa520a20e8ce031',
     'SemEval17-Task2/trial/subtask1-monolingual/output/de.trial.sample.output.txt':
     'f85cba9f6690d61736623c16e620826b09384aa5',
     'SemEval17-Task2/trial/subtask1-monolingual/output/en.trial.sample.output.txt':
     'f85cba9f6690d61736623c16e620826b09384aa5',
     'SemEval17-Task2/trial/subtask1-monolingual/output/es.trial.sample.output.txt':
     'f85cba9f6690d61736623c16e620826b09384aa5',
     'SemEval17-Task2/trial/subtask1-monolingual/output/fa.trial.sample.output.txt':
     'f85cba9f6690d61736623c16e620826b09384aa5',
     'SemEval17-Task2/trial/subtask1-monolingual/output/it.trial.sample.output.txt':
     'f85cba9f6690d61736623c16e620826b09384aa5',
     'SemEval17-Task2/trial/subtask2-crosslingual/data/de-es.trial.data.txt':
     'c27c8977d8d4434fdc3e59a7b0121d87e0a03237',
     'SemEval17-Task2/trial/subtask2-crosslingual/data/de-fa.trial.data.txt':
     '88a6f6dd1bba309f7cae7281405e37f442782983',
     'SemEval17-Task2/trial/subtask2-crosslingual/data/de-it.trial.data.txt':
     'ebdab0859f3b349fa0120fc8ab98be3394f0d73d',
     'SemEval17-Task2/trial/subtask2-crosslingual/data/en-de.trial.data.txt':
     '128d1a460fe9836b66f0fcdf59455b02edb9f258',
     'SemEval17-Task2/trial/subtask2-crosslingual/data/en-es.trial.data.txt':
     '508c5dde8ffcc32ee3009a0d020c7c96a338e1d1',
     'SemEval17-Task2/trial/subtask2-crosslingual/data/en-fa.trial.data.txt':
     '1a3640eb5facfe15b1e23a07183a2e62ed80c7d9',
     'SemEval17-Task2/trial/subtask2-crosslingual/data/en-it.trial.data.txt':
     '141c83d591b0292016583d9c23a2cc5514a006aa',
     'SemEval17-Task2/trial/subtask2-crosslingual/data/es-fa.trial.data.txt':
     'a0a548cd698c389ee80c34d6ec72abed5f1625e5',
     'SemEval17-Task2/trial/subtask2-crosslingual/data/es-it.trial.data.txt':
     '8d42bed8a43ff93d26ca95794758d9392ca707ed',
     'SemEval17-Task2/trial/subtask2-crosslingual/data/it-fa.trial.data.txt':
     '9c85223f1f734de61c28157df0ce417bb0537803',
     'SemEval17-Task2/trial/subtask2-crosslingual/keys/de-es.trial.gold.txt':
     '126c92b2fb3b8f2784dd4ae2a4c52b02a87a8196',
     'SemEval17-Task2/trial/subtask2-crosslingual/keys/de-fa.trial.gold.txt':
     '1db6201c2c8f19744c39dbde8bd4a803859d64c1',
     'SemEval17-Task2/trial/subtask2-crosslingual/keys/de-it.trial.gold.txt':
     '5300bf2ead163ff3981fb41ec5d0e291c287c9e0',
     'SemEval17-Task2/trial/subtask2-crosslingual/keys/en-de.trial.gold.txt':
     'd4f5205de929bb0c4020e1502a3f2204b5accd51',
     'SemEval17-Task2/trial/subtask2-crosslingual/keys/en-es.trial.gold.txt':
     '3237e11c3a0d9c0f5d583f8dc1d025b97a1f8bfe',
     'SemEval17-Task2/trial/subtask2-crosslingual/keys/en-fa.trial.gold.txt':
     'c14de7bf326907336a02d499c9b92ab229f3f4f8',
     'SemEval17-Task2/trial/subtask2-crosslingual/keys/en-it.trial.gold.txt':
     '3c0276c4b4e7a6d8a618bbe1ab0f30ad7b07929c',
     'SemEval17-Task2/trial/subtask2-crosslingual/keys/es-fa.trial.gold.txt':
     '359f69e9dfd6411a936baa3392b8f05c398a7707',
     'SemEval17-Task2/trial/subtask2-crosslingual/keys/es-it.trial.gold.txt':
     '44090607fabe5a26926a384e521ef1317f6f00d0',
     'SemEval17-Task2/trial/subtask2-crosslingual/keys/it-fa.trial.gold.txt':
     '97b09ffa11803023c2143fd4a4ac4bbc9775e645',
     'SemEval17-Task2/trial/subtask2-crosslingual/output/de-es.trial.sample.output.txt':
     'a0735361a692be357963959728dacef85ea08240',
     'SemEval17-Task2/trial/subtask2-crosslingual/output/de-fa.trial.sample.output.txt':
     'b71166d8615e921ee689cefc81419398d341167f',
     'SemEval17-Task2/trial/subtask2-crosslingual/output/de-it.trial.sample.output.txt':
     'b71166d8615e921ee689cefc81419398d341167f',
     'SemEval17-Task2/trial/subtask2-crosslingual/output/en-de.trial.sample.output.txt':
     'b71166d8615e921ee689cefc81419398d341167f',
     'SemEval17-Task2/trial/subtask2-crosslingual/output/en-es.trial.sample.output.txt':
     'b71166d8615e921ee689cefc81419398d341167f',
     'SemEval17-Task2/trial/subtask2-crosslingual/output/en-fa.trial.sample.output.txt':
     'a0735361a692be357963959728dacef85ea08240',
     'SemEval17-Task2/trial/subtask2-crosslingual/output/en-it.trial.sample.output.txt':
     'a0735361a692be357963959728dacef85ea08240',
     'SemEval17-Task2/trial/subtask2-crosslingual/output/es-fa.trial.sample.output.txt':
     'b71166d8615e921ee689cefc81419398d341167f',
     'SemEval17-Task2/trial/subtask2-crosslingual/output/es-it.trial.sample.output.txt':
     'b71166d8615e921ee689cefc81419398d341167f',
     'SemEval17-Task2/trial/subtask2-crosslingual/output/it-fa.trial.sample.output.txt':
     'a0735361a692be357963959728dacef85ea08240'}

UD21_DATA_FILE_SHA1 = \
    {'af': {'dev': ('af-ud-dev.conllu',
                    'e37b104f4425ee00afc81779201816d5ac525194'),
            'test': ('af-ud-test.conllu',
                     'd2bf02370d308ee957c04242bd0871db0e488389'),
            'train': ('af-ud-train.conllu',
                      'a652c7b19c236063d3ea489947f83095893b699a')},
     'grc_proiel': {'dev': ('grc_proiel-ud-dev.conllu',
                            'd199530c7e40ff0214e510957bb126af0dc12c1c'),
                    'test': ('grc_proiel-ud-test.conllu',
                             'bb7825ddeb18fc2d86638e4725f04563f3e08aab'),
                    'train': ('grc_proiel-ud-train.conllu',
                              'fe6c861299b033abe8c4ce2b6131cd74f87b96a7')},
     'grc': {'dev': ('grc-ud-dev.conllu',
                     'debdfec0272cd558ccd29fe0ae2f13175dd20a33'),
             'test': ('grc-ud-test.conllu',
                      'f19accf31db95e2c736d716d3438c09aa877eb07'),
             'train': ('grc-ud-train.conllu',
                       'e98d3eabea67787c5d43a498f5a0fa4246f38104')},
     'ar_nyuad': {'dev': ('ar_nyuad-ud-dev.conllu',
                          'b740de9bd68e68b30b9b313eb050d44e94470ca5'),
                  'test': ('ar_nyuad-ud-test.conllu',
                           'f5d5b8979b7fedd76235d4bae77e0b4a7b0a750a'),
                  'train': ('ar_nyuad-ud-train.conllu',
                            'd065f03958fd8782a7431b6778c6665ad09444a6')},
     'ar_pud': {'test': ('ar_pud-ud-test.conllu',
                         '2161701e6726b6feb14733a312fba6160b9eb722')},
     'ar': {'dev': ('ar-ud-dev.conllu',
                    '5f8964974d5ba5eb3504cdafb93c34c473c4177c'),
            'test': ('ar-ud-test.conllu',
                     '58df161047f310cc3bb4d0e615ca33466e630bb9'),
            'train': ('ar-ud-train.conllu',
                      '0a3d5cefa1fecd6a74f2016ee73ea7a7a02eb359')},
     'eu': {'dev': ('eu-ud-dev.conllu',
                    '3ee15b5ed46ec93d7278c8cc0351d242417d553d'),
            'test': ('eu-ud-test.conllu',
                     'aa68d6442ac6dc1abedc19c1b98c4a9944786188'),
            'train': ('eu-ud-train.conllu',
                      'd56ec997916e38ee6ab1badd78c119e81e4797c9')},
     'be': {'dev': ('be-ud-dev.conllu',
                    '015473e91cf8937c46e8b721f206415abac16a35'),
            'test': ('be-ud-test.conllu',
                     'f009ea1885f54cfd77fca8a2c89133b2af8f9f5e'),
            'train': ('be-ud-train.conllu',
                      '26b871e28d2f356a709f106b6e3e86b417ba74e7')},
     'bg': {'dev': ('bg-ud-dev.conllu',
                    '0a2284b10547681eb65691eb2a9f0f1662e16e90'),
            'test': ('bg-ud-test.conllu',
                     '75ea2a5e1d55bb57efecae6ec2b5ac3cc1b37e57'),
            'train': ('bg-ud-train.conllu',
                      'd4b2fa267010c4486885c91f3af65ff66c8be94c')},
     'bxr': {'sample': ('bxr-ud-sample.conllu',
                        '9239bdd251a60820c71111ec54de9e7d58a8579d'),
             'test': ('bxr-ud-test.conllu',
                      '0a06e527454ae0b547153222f67eb5db94e528fd')},
     'yue': {'test': ('yue-ud-test.conllu',
                      'd91477c65aa75cd45489cca13f7a122066972bdb')},
     'ca': {'dev': ('ca-ud-dev.conllu',
                    '5737824f0afff0d07a43db331f102d62c6da2d96'),
            'test': ('ca-ud-test.conllu',
                     '0e28bd2a3b982515c1158194ad52bcbbe741e170'),
            'train': ('ca-ud-train.conllu',
                      'b5ff2392722d4a1df3bfc52fa5b8f2043b7aec0c')},
     'zh_cfl': {'test': ('zh_cfl-ud-test.conllu',
                         '32fe45cd0e4e11ced95202971bce74acbc6a8c30')},
     'zh_hk': {'test': ('zh_hk-ud-test.conllu',
                        '4c75fa5bbcdcb181447b4e037224d50feb2776fb')},
     'zh_pud': {'test': ('zh_pud-ud-test.conllu',
                         'b3e448884b7b6229379f9723b97c6e9a6fedcb61')},
     'zh': {'dev': ('zh-ud-dev.conllu',
                    '34d8253b35ad2245d59ddffa71b5689ef267b6b2'),
            'test': ('zh-ud-test.conllu',
                     '0f00516097650c12262298dd0fbd1b17a6d2bfe2'),
            'train': ('zh-ud-train.conllu',
                      '9444eec5f4561f289ad140e47e49013689512a65')},
     'cop': {'dev': ('cop-ud-dev.conllu',
                     '863d1004df1a92df52515105f6fae6ff68539595'),
             'test': ('cop-ud-test.conllu',
                      'd3b33566679f071d4ad622ad840cd98381835706'),
             'train': ('cop-ud-train.conllu',
                       '33d0e5de5d6077f7c52a4cd90bce0047f3e9ff6f')},
     'hr': {'dev': ('hr-ud-dev.conllu',
                    '8da2a419980807d2e91e09b6bf496e58d442b0ba'),
            'test': ('hr-ud-test.conllu',
                     '49d673cba3d32d39d413e557276a45a0214ed83e'),
            'train': ('hr-ud-train.conllu',
                      'e5cc686bb46c80c84c3ac60ed459e1f124c04c08')},
     'cs_cac': {'dev': ('cs_cac-ud-dev.conllu',
                        '69dfed28c29146b41a3428f4715bde70a6aecf00'),
                'test': ('cs_cac-ud-test.conllu',
                         'a994b33ebbde486c1818a9df460fb112055e95de'),
                'train': ('cs_cac-ud-train.conllu',
                          '694f8559471dc481612606bf5df078daa094a84e')},
     'cs_cltt': {'dev': ('cs_cltt-ud-dev.conllu',
                         'f35d5dbe57cd95760901ea29de4f493d5d2a44d4'),
                 'test': ('cs_cltt-ud-test.conllu',
                          'a8f6696785e658471f759bc736b738a105cba9a3'),
                 'train': ('cs_cltt-ud-train.conllu',
                           'ab97886066bfa462e5da03d25f802489292c0b56')},
     'cs_fictree': {'dev': ('cs_fictree-ud-dev.conllu',
                            'dc67c07737a3a8bf2633068941f2d55f1500e192'),
                    'test': ('cs_fictree-ud-test.conllu',
                             '06becaedef1cfdb8e1b2dce3f0d3a3a607d178a4'),
                    'train': ('cs_fictree-ud-train.conllu',
                              'fe7dbe3a0e6ee73e19e788c43bbb8f8f47ae1645')},
     'cs_pud': {'test': ('cs_pud-ud-test.conllu',
                         '9f205677041de694157ba2ef3e1eadb44d467f2f')},
     'cs': {'dev': ('cs-ud-dev.conllu',
                    'd609e895b21b8710337e23a98b58ffd7b7a54bf1'),
            'test': ('cs-ud-test.conllu',
                     '34091286a11b1ce2a9c8bcfa03fdd86fb0e13965'),
            'train': ('cs-ud-train.conllu',
                      'd1f855798a29d433b580d01ade0d8d062cd58534')},
     'da': {'dev': ('da-ud-dev.conllu',
                    '2c0c798c20a2efb30273172d388342a82bb0ce3c'),
            'test': ('da-ud-test.conllu',
                     '85a95a8527f8773f1575ceaf0ab51f204b211047'),
            'train': ('da-ud-train.conllu',
                      'b653c029a7ae5c106f865dcef949fb3fe2aa0420')},
     'nl_lassysmall': {'dev': ('nl_lassysmall-ud-dev.conllu',
                               '2a169af74c2206c9073c3932b4a300492a314ee5'),
                       'test': ('nl_lassysmall-ud-test.conllu',
                                '39f08896a40ad370f2acc37d58689cdc43a660a9'),
                       'train': ('nl_lassysmall-ud-train.conllu',
                                 'e4fd6bac246c81bb17a3c932e251b8662739cc19')},
     'nl': {'dev': ('nl-ud-dev.conllu',
                    '33a9387eef9f5c0b15bd1e76e78776863f1f6d90'),
            'test': ('nl-ud-test.conllu',
                     '01b3e1048792c851fdd59882c353fcdb76dc165e'),
            'train': ('nl-ud-train.conllu',
                      '8e6a10152b7d09ce61433dd5f715ab2401611cf6')},
     'en_lines': {'dev': ('en_lines-ud-dev.conllu',
                          '83b63b7670ea4394b558bc26e16a004339f0a0ef'),
                  'test': ('en_lines-ud-test.conllu',
                           'ccc9d3c71a873313d138c3adb12405a97eb270d8'),
                  'train': ('en_lines-ud-train.conllu',
                            'da42bfac9fd97d98ebbbc37c65d83ff4c53b4e79')},
     'en_pud': {'test': ('en_pud-ud-test.conllu',
                         '4a9c83ba058a7e51979af790ba0440cc274b948f')},
     'en_partut': {'dev': ('en_partut-ud-dev.conllu',
                           '863a6f571158acaaca95223e50bd08fc0c1134f0'),
                   'test': ('en_partut-ud-test.conllu',
                            '0c0780b0f14e4623f1014e6496d639cd2d2f6ffd'),
                   'train': ('en_partut-ud-train.conllu',
                             'e00a2d6f7efa28c8aaa40dccdf29b59a50f48e18')},
     'en': {'dev': ('en-ud-dev.conllu',
                    'e2159dda4400d289ad8a403b466c8d23d733ba35'),
            'test': ('en-ud-test.conllu',
                     'bd36ef23f76155625b379d063427bd62f19b7658'),
            'train': ('en-ud-train.conllu',
                      '993c44f62104971fe2d056847349facbb7986258')},
     'et': {'dev': ('et-ud-dev.conllu',
                    '312f9477f7ee1dd380c1fbcf77a6f0c63476fdbb'),
            'test': ('et-ud-test.conllu',
                     'd70907f0771b41a27406672b9d91043a0954f946'),
            'train': ('et-ud-train.conllu',
                      'b6d788e7a3362d0984d1cff06c1ba3d66f6bf773')},
     'fi_ftb': {'dev': ('fi_ftb-ud-dev.conllu',
                        '552ec574acdb3209e7545af4e16a43a1e2956979'),
                'test': ('fi_ftb-ud-test.conllu',
                         '13c34838a0fa9e379f9624ed1f4c368ca50a7d98'),
                'train': ('fi_ftb-ud-train.conllu',
                          '73d025250bfc82a24181b5ed601dc4ae7c8e846c')},
     'fi_pud': {'test': ('fi_pud-ud-test.conllu',
                         '4ab7b0d99ce6697d79732e401be97585a28c2afa')},
     'fi': {'dev': ('fi-ud-dev.conllu',
                    'e023cf7eaffbda20bd4518d87fe9086207bb5361'),
            'test': ('fi-ud-test.conllu',
                     'fd57c5106e43994250f4472890572bdbb8b4a48b'),
            'train': ('fi-ud-train.conllu',
                      'ab27bda8cbb62886196b78de87985a4c6cf8215d')},
     'fr_ftb': {'dev': ('fr_ftb-ud-dev.conllu',
                        '71b3cc02601f64711f98e33a6b2af10aa00700be'),
                'test': ('fr_ftb-ud-test.conllu',
                         '723b8c44e74202a18b7e71268b738a5e1aa15f86'),
                'train': ('fr_ftb-ud-train.conllu',
                          '9a347120478254647deb7c7e02871b28aad23ec4')},
     'fr_pud': {'test': ('fr_pud-ud-test.conllu',
                         '570b7e31dc359ed62123bea6546efa13cfc2cf25')},
     'fr_partut': {'dev': ('fr_partut-ud-dev.conllu',
                           '1505030048829a8dccc466cc86bca057996301ae'),
                   'test': ('fr_partut-ud-test.conllu',
                            'f6446317c9f82cc0b70a76be75282804a3359ac0'),
                   'train': ('fr_partut-ud-train.conllu',
                             'f87c246cfa91186b90c7780cb64783034f196622')},
     'fr_sequoia': {'dev': ('fr_sequoia-ud-dev.conllu',
                            '859b10d80c7b3a382571cce9b2620039673539d1'),
                    'test': ('fr_sequoia-ud-test.conllu',
                             'be0ef69e392e64030414748da2995433f23e033d'),
                    'train': ('fr_sequoia-ud-train.conllu',
                              '48ac01913518888a32670a687123ed1bac57e0e9')},
     'fr': {'dev': ('fr-ud-dev.conllu',
                    '5de0aee778bcc69d14285ada88f0ff7e5ac0a0cd'),
            'test': ('fr-ud-test.conllu',
                     'd20a014acd38193155a33a5233c13f89541c78c3'),
            'train': ('fr-ud-train.conllu',
                      'feee0cc85a2d7dcb3397399ef22c8af8ef75420b')},
     'gl_treegal': {'dev': ('gl_treegal-ud-dev.conllu',
                            '272558614cff4a5e1f2805626904e6dc488b8d25'),
                    'test': ('gl_treegal-ud-test.conllu',
                             '18d99474d3aa9c83878c42a79d7881330dd9b861'),
                    'train': ('gl_treegal-ud-train.conllu',
                              'b1691dd5f587a19eb9dc6f141ecbd3eec3bb0e07')},
     'gl': {'dev': ('gl-ud-dev.conllu',
                    'e72390dce9bf973442deef31ed0cd7a975361fe5'),
            'test': ('gl-ud-test.conllu',
                     '7d82ba3672bd4427674428e1dcbcae4feebc3aeb'),
            'train': ('gl-ud-train.conllu',
                      'd586e7bffa314f8c5b85288e060e68dddc1f5d33')},
     'de_pud': {'test': ('de_pud-ud-test.conllu',
                         '2c91e42b7345145290b68385ff5270910048b8c4')},
     'de': {'dev': ('de-ud-dev.conllu',
                    '9b4f49bfa2b609d54369890d9e7d8d24a3c229af'),
            'test': ('de-ud-test.conllu',
                     '48f0f6f98b38710906481b5e9fe1d459d28f1b4a'),
            'train': ('de-ud-train.conllu',
                      '04a1d6a6a2da9d9c38496118e0432c9a6720db64')},
     'got': {'dev': ('got-ud-dev.conllu',
                     '501c47193ca2af5826e4afcc04941df87a7c47c3'),
             'test': ('got-ud-test.conllu',
                      'cfcf16d562434987562bd1f5faa0d8c007e9ddb8'),
             'train': ('got-ud-train.conllu',
                       'b4951ede89d947c6617df782ac248566235f78fb')},
     'el': {'dev': ('el-ud-dev.conllu',
                    '9df0919ed6f9dcab3ba3f60f0ad31d0c79ae6cdb'),
            'test': ('el-ud-test.conllu',
                     '1bb4a6b24521f0c3c7d6cf71e2456ef3a1ee31aa'),
            'train': ('el-ud-train.conllu',
                      '32f4abc821624c4cd4d3b3b555c1558f06366e2c')},
     'he': {'dev': ('he-ud-dev.conllu',
                    'c5b76874fcf11c7733e1555957bb49e8298af140'),
            'test': ('he-ud-test.conllu',
                     '4fbe4115948250fc2e42dd43399d1c6c11ddcfd2'),
            'train': ('he-ud-train.conllu',
                      'eae49a515b38d224b109138bf006a112e80a7caf')},
     'hi_pud': {'test': ('hi_pud-ud-test.conllu',
                         'd237fecc594186e7a52ad33313ac52e927905d73')},
     'hi': {'dev': ('hi-ud-dev.conllu',
                    '48b592bb1aa1cbc30d41d2913421cfd3f9d2c790'),
            'test': ('hi-ud-test.conllu',
                     '004a7fdde368f32f9f230bc5e2cf4ce9e1d8f8d7'),
            'train': ('hi-ud-train.conllu',
                      '9be8afb2cabda361817c55b3de6ebba2c3fef7e0')},
     'hu': {'dev': ('hu-ud-dev.conllu',
                    'ec622e6bcf2a84b0b47eba0de01cf5768157a50e'),
            'test': ('hu-ud-test.conllu',
                     'fd717d25add38c2fb2dc8e82e2f9e5b0b9f3c5b8'),
            'train': ('hu-ud-train.conllu',
                      'e5486523a8bebe40d633ad8b4050be8a3d11c78a')},
     'id': {'dev': ('id-ud-dev.conllu',
                    '7b181aa954a4f4b22b80a18e4f67cbf423e9c701'),
            'test': ('id-ud-test.conllu',
                     '357ed8c216725760bf5be561ed6e918ce602b5ac'),
            'train': ('id-ud-train.conllu',
                      '328ea588b75de55ef48373c2bf9983bca277d724')},
     'ga': {'dev': ('ga-ud-dev.conllu',
                    '180a1a9dcfcec6528a559032c67e9a15693a039d'),
            'test': ('ga-ud-test.conllu',
                     'b74a56372af3f68f089ea82ba858e5a82aae4e22'),
            'train': ('ga-ud-train.conllu',
                      '40df0b12fbadae6e56c0a01da483d6c612d9450c')},
     'it_pud': {'test': ('it_pud-ud-test.conllu',
                         'c7121c03dbdc7d27f89c6f6dd8f046b89233438e')},
     'it_partut': {'dev': ('it_partut-ud-dev.conllu',
                           '0bb5dc0c0815212c9832eaef3b802cf885e0543b'),
                   'test': ('it_partut-ud-test.conllu',
                            'b5eccd3d9a94a2f96c8c3a6e4192a287ac563898'),
                   'train': ('it_partut-ud-train.conllu',
                             '784b18bf8d3b59d967d147075a3cb5b03fb28637')},
     'it_postwita': {'dev': ('it_postwita-ud-dev.conllu',
                             '07f6f658246aa070e2166e688f7569d61aafff54'),
                     'test': ('it_postwita-ud-test.conllu',
                              'c2d58f50e51d37cb5f55bd0a3129138e95a72a8a'),
                     'train': ('it_postwita-ud-train.conllu',
                               '69684c47fba99230f6ef1a204b95c37d28eaa5a6')},
     'it': {'dev': ('it-ud-dev.conllu',
                    'ea8fd59f36280fbd77b9a807959491636048a698'),
            'test': ('it-ud-test.conllu',
                     '34839fdeeef883f8034c723a18772947106cec6b'),
            'train': ('it-ud-train.conllu',
                      'a0cae413f46a344366f86bc7ffe4f5d7ecbf6a14')},
     'ja_pud': {'test': ('ja_pud-ud-test.conllu',
                         '4c914016a0968ca434348370d38c9579a60e8fd7')},
     'ja': {'dev': ('ja-ud-dev.conllu',
                    '21f06fef7fbeccd05a298385bf40f8b4ffe95146'),
            'test': ('ja-ud-test.conllu',
                     '240d3532698356a7c6f93c3215718ef2f66a672f'),
            'train': ('ja-ud-train.conllu',
                      '35eaf307d94c2006241fe08f745d7b1b17f049cf')},
     'kk': {'dev': ('kk-ud-dev.conllu',
                    '038033c822b407040a4ecb87c077506cd0d1a322'),
            'test': ('kk-ud-test.conllu',
                     '4124bcaa6e4fc132613d94a882abcff8ecad8ca0'),
            'train': ('kk-ud-train.conllu',
                      '48d664d273ad6731cb65228ce9b57ad3cf50f7f5')},
     'ko': {'dev': ('ko-ud-dev.conllu',
                    '60e7da7cca44c923873a062e80262726659f5528'),
            'test': ('ko-ud-test.conllu',
                     'bc9a0fc4ddfed14b70bb58048bf8b8d50062cffd'),
            'train': ('ko-ud-train.conllu',
                      'ee21328f9ea39668e802f0cb6a794358f5c256bf')},
     'kmr': {'sample': ('kmr-ud-sample.conllu',
                        'd76d631400d17b63b9592ce3c0f4ecada012d6d0'),
             'test': ('kmr-ud-test.conllu',
                      '606a338db2d6adde6b4d7d8c9ee2bdf1f988d729')},
     'la_ittb': {'dev': ('la_ittb-ud-dev.conllu',
                         'd9f17992bd0258a734aea9b6c53759039717c86a'),
                 'test': ('la_ittb-ud-test.conllu',
                          'f4d097d076083240c48594d4cb058840ff16be8e'),
                 'train': ('la_ittb-ud-train.conllu',
                           '627d5b30b20655efab194c75fc9219b0aa2cf4b6')},
     'la_proiel': {'dev': ('la_proiel-ud-dev.conllu',
                           '9a510ff1f29b507ce46d32c04eb8f02ec8bdb4fb'),
                   'test': ('la_proiel-ud-test.conllu',
                            '697dbeae38507856a4fafa8506dfc8db5e8e4054'),
                   'train': ('la_proiel-ud-train.conllu',
                             '5e57e0a83ed8dcdfcc892c2558249cb6bc02b37a')},
     'la': {'dev': ('la-ud-dev.conllu',
                    '2748bb0479cb599e1a007d1d1634d5870b45549b'),
            'test': ('la-ud-test.conllu',
                     '19c62c64ce41a650e9b55a345c61e7c0d994816e'),
            'train': ('la-ud-train.conllu',
                      '183ce6f58b0305e5926161e29b9a6aacc424662c')},
     'lv': {'dev': ('lv-ud-dev.conllu',
                    '6bf3843d92aeb5b4a5e3b457708ad0aca176fbd2'),
            'test': ('lv-ud-test.conllu',
                     '9f7806a24656db0e859efe041a88926b220b8e28'),
            'train': ('lv-ud-train.conllu',
                      'f1eeff608e8f27d92b683ae041591355198841eb')},
     'lt': {'dev': ('lt-ud-dev.conllu',
                    '0b8dc19005571fa7b66d8302b797d51a241f128b'),
            'test': ('lt-ud-test.conllu',
                     'def54d6caf97610eb4ca8c0179d661c8eab98951'),
            'train': ('lt-ud-train.conllu',
                      '13fe42a3d21f17a5cad5aaf38692619c7713e177')},
     'mr': {'dev': ('mr-ud-dev.conllu',
                    'abf7ac90a3696bb979e6ddc17cbc0fc761040b1b'),
            'test': ('mr-ud-test.conllu',
                     'b70e2a135e69dc17474951bfd9c7cf3f203d4798'),
            'train': ('mr-ud-train.conllu',
                      '24a1370184054a7f5af647997dca783d6c571242')},
     'sme': {'sample': ('sme-ud-sample.conllu',
                        '8c456f06b363c4d273fc454a49505f783f00fe43'),
             'test': ('sme-ud-test.conllu',
                      '6c2084f60d7f2d1468a0cb4f4a4b9669274b122e'),
             'train': ('sme-ud-train.conllu',
                       '203eab4183fd585efe3fea7e6df493a6746b0a9f')},
     'no_bokmaal': {'dev': ('no_bokmaal-ud-dev.conllu',
                            '3a1aa6646ee62c605a6e5a7b535434ce93d0581f'),
                    'test': ('no_bokmaal-ud-test.conllu',
                             '18336ef0e4877ae28eb7d6019afe05b5a53245d5'),
                    'train': ('no_bokmaal-ud-train.conllu',
                              'c6a1d75956dfb9376e568bf241b3ee5ebf3be3a5')},
     'no_nynorsk': {'dev': ('no_nynorsk-ud-dev.conllu',
                            '5b95a070d11a61a23fc340ecbbbbb70f86884498'),
                    'test': ('no_nynorsk-ud-test.conllu',
                             '3eaab8e4af82de2333521e9be0954ffaf6b1440b'),
                    'train': ('no_nynorsk-ud-train.conllu',
                              '79319993097c30ddf28d4c1137b8662f4f35d17e')},
     'no_nynorsklia': {'dev': ('no_nynorsklia-ud-dev.conllu',
                               'f3e3cc9b156784c12e7540b6e09a19963df8d7d9'),
                       'test': ('no_nynorsklia-ud-test.conllu',
                                'c43abf4ad0d9c1d844edb9ff0fdf8b00949c4a0b')},
     'cu': {'dev': ('cu-ud-dev.conllu',
                    '0b67035ed5ca52aeefae443611232ed202fb990a'),
            'test': ('cu-ud-test.conllu',
                     '0fed872a5a2480b601c67ebbecf8dcd680b6863b'),
            'train': ('cu-ud-train.conllu',
                      '1c58f7322b96aa65e2b6bbeb5cb5226b46dc3ef0')},
     'fa': {'dev': ('fa-ud-dev.conllu',
                    '098f97ff4c0a6a9dcaafe2c83908b1ff044b4446'),
            'test': ('fa-ud-test.conllu',
                     '0024aa6bad5eceed2e36f77d88578304a5886a80'),
            'train': ('fa-ud-train.conllu',
                      '1692f90f58fb1ed2faaa4e8c5d2d47a37c47082b')},
     'pl': {'dev': ('pl-ud-dev.conllu',
                    'b7af7bee091feb0788eb9793a7102972006421dc'),
            'test': ('pl-ud-test.conllu',
                     'e141e793ba35f8a08510ec1ce494099b5c800ca8'),
            'train': ('pl-ud-train.conllu',
                      'f2227ba184a5030fc47b1aff732e04ae11b9ab94')},
     'pt_br': {'dev': ('pt_br-ud-dev.conllu',
                       '8eedc77096a87fe8ab251100d460780e161e5397'),
               'test': ('pt_br-ud-test.conllu',
                        '37a64e3acef107b62ab62ce478fc36ed112fb58f'),
               'train': ('pt_br-ud-train.conllu',
                         '023cafcb6959d52298ad619f7838f26db9798aa9')},
     'pt_pud': {'test': ('pt_pud-ud-test.conllu',
                         '4f7a98b59255ff58a1a423dda6f2cb7261dcea7d')},
     'pt': {'dev': ('pt-ud-dev.conllu',
                    '2171b4ac2b0726c9dfae6adf394b76be927accab'),
            'test': ('pt-ud-test.conllu',
                     '9e819a4592db42905806141d6fca3b7b20396ce3'),
            'train': ('pt-ud-train.conllu',
                      'b5fbb6598d5cc53a0f7e699adeb4a61948a49b5c')},
     'ro_nonstandard': {'test': ('ro_nonstandard-ud-test.conllu',
                                 '300d53091412dc5700dc5cad0fd3e136f7c8cb11'),
                        'train': ('ro_nonstandard-ud-train.conllu',
                                  'ed97f51129b63857627f838f68f41c9ef8541686')},
     'ro': {'dev': ('ro-ud-dev.conllu',
                    'a320e29582e837fa48bbe0aab8e205cadfcb4a02'),
            'test': ('ro-ud-test.conllu',
                     '0cfe4806a28ebdc02dc7ea58635d8b550c3a9d7b'),
            'train': ('ro-ud-train.conllu',
                      '74beb2aa92d2fca50dbb1a4f716b936afb436ab9')},
     'ru_pud': {'test': ('ru_pud-ud-test.conllu',
                         'bca81ce7aaf3cb8add98b19faecc1d8303901631')},
     'ru_syntagrus': {'dev': ('ru_syntagrus-ud-dev.conllu',
                              '304c6ec7fb5060583af5f890384e3a480f8c3ad5'),
                      'test': ('ru_syntagrus-ud-test.conllu',
                               'c138e39b48dc1c66d106e68ee75c6fce28ef780c'),
                      'train': ('ru_syntagrus-ud-train.conllu',
                                '8fa56fa80845e4ad946189d1e7af228b5595e312')},
     'ru': {'dev': ('ru-ud-dev.conllu',
                    'd3b11c0fd8a87bfb7ce9666a1888126ae5ddca90'),
            'test': ('ru-ud-test.conllu',
                     'ae13bbf49e0d2fddae8ba2eeacd15a9a77c7bfff'),
            'train': ('ru-ud-train.conllu',
                      'fd43e7323ad2e62a6924fc5b5d48e85c6ab5a430')},
     'sa': {'test': ('sa-ud-test.conllu',
                     'fad3a03a6834884a092b1d326625c6f663e36636')},
     'sr': {'dev': ('sr-ud-dev.conllu',
                    'dcb9a242986285e83512ddaa4b3ada07c4cea17a'),
            'test': ('sr-ud-test.conllu',
                     '0f0c9e394c440bb2dd514bdd6873d3ffef13821b'),
            'train': ('sr-ud-train.conllu',
                      '97ea9bfe4ac97011598fbb5ca20b5cbaf5093334')},
     'sk': {'dev': ('sk-ud-dev.conllu',
                    'c84563c08922d60b0c765e9f9c22d9f6f2765ff9'),
            'test': ('sk-ud-test.conllu',
                     '89af4581c5f9058809f48788eb635a92cda0603c'),
            'train': ('sk-ud-train.conllu',
                      '89e108093bbf5619578955fdadfe200cefd8cf01')},
     'sl_sst': {'dev': ('sl_sst-ud-dev.conllu',
                        'c65ae82123af95ec11f47262546b5ab2fc5735e5'),
                'test': ('sl_sst-ud-test.conllu',
                         '144a0124c1181b49d0c542a4a6d4465e45545f3b'),
                'train': ('sl_sst-ud-train.conllu',
                          '4cbb97d5c19cfb1d85cdd54a13e24de2343a4ac5')},
     'sl': {'dev': ('sl-ud-dev.conllu',
                    '0078572c19574d32defeae9924176da2dd701ede'),
            'test': ('sl-ud-test.conllu',
                     '616ace00e25df99be8dd49b7bf7c48f1093df96a'),
            'train': ('sl-ud-train.conllu',
                      '1462ac69163b30cf1399527e95f686ebf91be2d3')},
     'es_ancora': {'dev': ('es_ancora-ud-dev.conllu',
                           '94b00cc6449a1793b5ba1d9d5c1e4b34ad1cc7d5'),
                   'test': ('es_ancora-ud-test.conllu',
                            '8d7dc8d8441e1ca4b54708a5382ed61b48bf7920'),
                   'train': ('es_ancora-ud-train.conllu',
                             '95d5bf7ad33304f3440ffb014ac094c4967c303f')},
     'es_pud': {'test': ('es_pud-ud-test.conllu',
                         'c2b17fce1da3bdd2a50d9dd7eca101db1d2907e0')},
     'es': {'dev': ('es-ud-dev.conllu',
                    '4cdb828c492c6b7707af0ab6c7fbf734f770630a'),
            'test': ('es-ud-test.conllu',
                     'afd1ae1b7eb73a91456c30acf388eef4faf4785a'),
            'train': ('es-ud-train.conllu',
                      '5ce48b44ba1b3e748a40cb5bf893d3096518ecbc')},
     'sv_lines': {'dev': ('sv_lines-ud-dev.conllu',
                          '15f1a04d960518fe7bfee23ce227fc7b78d4b755'),
                  'test': ('sv_lines-ud-test.conllu',
                           '843df4ea3ab4f551b1eaa661652a8d6489a81d41'),
                  'train': ('sv_lines-ud-train.conllu',
                            '16e3533bf174b36d728847a36a3600f16c63baa6')},
     'sv_pud': {'test': ('sv_pud-ud-test.conllu',
                         '18dadac0c15468256b340835ebc0529facbe9b73')},
     'sv': {'dev': ('sv-ud-dev.conllu',
                    '6d14e1aae5c9ae37c35481c44c04bf74a4233455'),
            'test': ('sv-ud-test.conllu',
                     '7ead0f7b49508db0022c042195ac5925b611c5b7'),
            'train': ('sv-ud-train.conllu',
                      '68affb85efde6ed017eab1e998e9666108559e04')},
     'swl': {'dev': ('swl-ud-dev.conllu',
                     '828e0a08f12cabfa75f9dd2b53dba58606522a7c'),
             'test': ('swl-ud-test.conllu',
                      '674f76631cf16172d67b795ff92dfbb297eb4930'),
             'train': ('swl-ud-train.conllu',
                       '46b721f9cae2d5ba43f818dd487600b0ce76362a')},
     'ta': {'dev': ('ta-ud-dev.conllu',
                    '4d01f555012ddc1976933d4d928e26470f71bfa1'),
            'test': ('ta-ud-test.conllu',
                     'e8db8816a98d8b7e81188786db7c405979a7e3c3'),
            'train': ('ta-ud-train.conllu',
                      '6753d8c7b1b016de39c087aab45056de6021c3ae')},
     'te': {'dev': ('te-ud-dev.conllu',
                    '29f46355d767e54e8565f76a063c43e95ead0fca'),
            'test': ('te-ud-test.conllu',
                     '50abe345d4ab5bae021cacd096266c57b00572b8'),
            'train': ('te-ud-train.conllu',
                      '1794469abe09e7364cda0d9764cf515dcb4a61b6')},
     'tr_pud': {'test': ('tr_pud-ud-test.conllu',
                         'aae839e2476a2f149c98e0274d245d07a50dafaa')},
     'tr': {'dev': ('tr-ud-dev.conllu',
                    '421de4d8d0fbdda46750523bde72880414c134a3'),
            'test': ('tr-ud-test.conllu',
                     'b175f136f6f0271c494a58a1846971c4a07cda27'),
            'train': ('tr-ud-train.conllu',
                      '5aeaf25fc9e00c75e377983a0d0a642e4df6ae7d')},
     'uk': {'dev': ('uk-ud-dev.conllu',
                    '0d3e3507edcd46a3eaa8c4702d0f5d84661a6d9d'),
            'test': ('uk-ud-test.conllu',
                     '46c88fd623894fabdafb01a826016c215e4f65cc'),
            'train': ('uk-ud-train.conllu',
                      'd06e0e2fa67c35a20517738bd728ac3b26d8eafe')},
     'hsb': {'sample': ('hsb-ud-sample.conllu',
                        '148eddbb19b06115ea54e17a3fca58e99a85cbd9'),
             'test': ('hsb-ud-test.conllu',
                      '3d319288b4c06395b2627980737131995949f770')},
     'ur': {'dev': ('ur-ud-dev.conllu',
                    'dc41e72b5adeb92f308cdc8dfcbf71f84b4a5cf9'),
            'test': ('ur-ud-test.conllu',
                     'af5da25be4c4ec1f2a222bc462b39ca4bbcc0eb0'),
            'train': ('ur-ud-train.conllu',
                      '488d65b394d0de264be1221614c09e541f92f9de')},
     'ug': {'dev': ('ug-ud-dev.conllu',
                    'a2e6cd7ef51ffd7c83de7c62fbad998f1020f857'),
            'test': ('ug-ud-test.conllu',
                     '4877323d8dbfaa8ab862f0aa8e5484fdadb9ef43')},
     'vi': {'dev': ('vi-ud-dev.conllu',
                    '1c733d3ea3e4cce00cb0aa4d599bcb3b0a6096a8'),
            'test': ('vi-ud-test.conllu',
                     '1bb822e58f21aa5ccac15fe6c6742a42e8389d41'),
            'train': ('vi-ud-train.conllu',
                      'ac86132afc061625740abd524c5cdf3d35ebbbc4')}}
